﻿/*  
     This file is part of Emulators Organizer
    A program that organize emulators and roms.
   
    Copyright (C) 2009 - 2012  Ali Hadid, programmed by Ala Hadid

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Linq;
using System.Text;
using System.IO;
using System.Windows.Forms;
using AHD.Emulators_Organizer.Base;
using AHD.Utilities;
using System.Diagnostics;

namespace EmulatorsOrganizer.Controls
{
    public partial class Cntr_ImagesBrowser : UserControl
    {
        Rom _rom;
        bool _IsCovers = false;
        int SelectedIndex = 0;
        bool _StreatchByDefault = false;
        string currentImagePath = "";
        Bitmap CurrentImage;
        int original_w = 0;
        int original_h = 0;
        /// <summary>
        /// Get or set the rom
        /// </summary>
        [DisplayName("Rom"), Category("Emulators Organizer"), Description("The rom to browse snapshots or covers for")]
        public Rom Rom
        {
            get { return _rom; }
            set
            {
                _rom = value;
                SelectedIndex = 0;
                if (value != null)
                {
                    ShowImage();
                }
                else
                {
                    pictureBox1.Visible = false;
                    if (pictureBox1.Image != null)
                        pictureBox1.Image.Dispose();
                    if (CurrentImage != null)
                        CurrentImage.Dispose();
                    pictureBox1.Image = null;
                    TextOfImages.Text = "N/A";
                    panel2.BackgroundImage = Properties.Resources.EmulatorsOrganizer;
                }
            }
        }
        /// <summary>
        /// Get or set the rom
        /// </summary>
        [DisplayName("Stretch by default"), Category("Image"), Description("If true, the control will stretch the image even the size of it is smaller than the control bounds")]
        public bool StreatchByDefault
        {
            get { return _StreatchByDefault; }
            set
            {
                _StreatchByDefault = value;
            }
        }
        /// <summary>
        /// Get or set if cover
        /// </summary>
        [DisplayName("Is covers"), Category("Emulators Organizer"), Description("If true, the browser will browse for covers instead of snapshots")]
        public bool IsCover
        { get { return _IsCovers; } set { _IsCovers = value; } }
        public Cntr_ImagesBrowser()
        {
            InitializeComponent();
        }
        void SetPictureBoxLocation()
        {
            int x = (panel2.Width / 2) - (pictureBox1.Width / 2);
            int y = (panel2.Height / 2) - (pictureBox1.Height / 2);
            if (x < 0)
                x = 0;
            if (y < 0)
                y = 0;
            pictureBox1.Location = new Point(x, y);
        }
        void FixSize()
        {
            if (CurrentImage != null)
            {
                pictureBox1.Visible = true;
                panel2.BackgroundImage = null;
                pictureBox1.SizeMode = PictureBoxSizeMode.AutoSize;
                if (_StreatchByDefault)
                {
                    pictureBox1.Image = CurrentImage;
                    pictureBox1.SizeMode = PictureBoxSizeMode.StretchImage;
                    pictureBox1.Location = new Point(0, 0);
                    pictureBox1.Size = new Size(panel2.Width, panel2.Height);
                }
                else if (CurrentImage.Size.Width > panel2.Width | CurrentImage.Size.Height > panel2.Height)
                {
                    pictureBox1.Image = CurrentImage;
                    pictureBox1.SizeMode = PictureBoxSizeMode.StretchImage;
                    pictureBox1.Location = new Point(0, 0);
                    pictureBox1.Size = new Size(panel2.Width, panel2.Height);
                }
                else
                    pictureBox1.Image = CurrentImage;
            }
            else
            {
                pictureBox1.Visible = false;
                panel2.BackgroundImage = Properties.Resources.EmulatorsOrganizer;
            }
        }
        void ShowImage()
        {
            pictureBox1.Image = null;
            if (!_IsCovers)//Snapshots
            {
                if (_rom.Snapshots != null)
                {
                    if (_rom.Snapshots.Count > 0)
                    {
                        try
                        {
                            currentImagePath = _rom.Snapshots[SelectedIndex];
                            Stream str = new FileStream(Utilities.GetFullPath(_rom.Snapshots[SelectedIndex]), FileMode.Open, FileAccess.Read);
                            byte[] buff = new byte[str.Length];
                            str.Read(buff, 0, (int)str.Length);
                            str.Dispose();
                            str.Close();
                            str = null;

                            MemoryStream stream = new MemoryStream(buff);
                            CurrentImage = new Bitmap(stream);
                            original_w = CurrentImage.Width;
                            original_h = CurrentImage.Height;
                            //stream.Close();

                            trackBar1.Value = 100;
                            pictureBox1.Image = CurrentImage;
                        }
                        catch
                        {
                            currentImagePath = "";
                            trackBar1.Value = 100;
                            CurrentImage = null;
                            pictureBox1.Image = null;
                            original_w = 0;
                            original_h = 0;
                            Graphics GR = pictureBox1.CreateGraphics();
                            GR.DrawString("Preview is not available", TextOfImages.Font, new SolidBrush(Color.Black), new PointF(2, 2));
                        }
                        TextOfImages.Text = (SelectedIndex + 1).ToString() + " of " + _rom.Snapshots.Count;
                    }
                    else
                    {
                        currentImagePath = "";
                        CurrentImage = null;
                        pictureBox1.Image = null;
                        TextOfImages.Text = "N/A";
                    }
                }
                else
                {
                    currentImagePath = "";
                    pictureBox1.Image = null; CurrentImage = null;
                    TextOfImages.Text = "N/A";
                }
            }
            else//covers
            {
                if (_rom.Covers != null)
                {
                    if (_rom.Covers.Count > 0)
                    {
                        try
                        {
                            currentImagePath = _rom.Covers[SelectedIndex];
                            Stream str = new FileStream(Utilities.GetFullPath(_rom.Covers[SelectedIndex]), FileMode.Open, FileAccess.Read);
                            byte[] buff = new byte[str.Length];
                            str.Read(buff, 0, (int)str.Length);
                            str.Dispose();
                            str.Close();
                            str = null;

                            MemoryStream stream = new MemoryStream(buff);
                            CurrentImage = new Bitmap(stream);
                            original_w = CurrentImage.Width;
                            original_h = CurrentImage.Height;
                            //stream.Close();

                            trackBar1.Value = 100;
                            pictureBox1.Image = CurrentImage;
                        }
                        catch
                        {
                            currentImagePath = "";
                            pictureBox1.Image = null;
                            CurrentImage = null;
                            original_w = 0;
                            original_h = 0;
                            Graphics GR = pictureBox1.CreateGraphics();
                            GR.DrawString("Preview is not available", TextOfImages.Font, new SolidBrush(Color.Black), new PointF(2, 2));
                        }
                        TextOfImages.Text = (SelectedIndex + 1).ToString() + " of " + _rom.Covers.Count;
                    }
                    else
                    {
                        currentImagePath = "";
                        CurrentImage = null;
                        pictureBox1.Image = null;
                        TextOfImages.Text = "N/A";
                    }
                }
                else
                {
                    currentImagePath = "";
                    pictureBox1.Image = null; CurrentImage = null;
                    TextOfImages.Text = "N/A";
                }
            }
            FixSize();
            SetPictureBoxLocation();
        }
        /// <summary>
        /// Riseded up when the user added image
        /// </summary>
        [DisplayName("Image Added"), Category("Emulators Organizer"), Description("Riseded up when the user added image")]
        public event EventHandler ImageAdded;
        /// <summary>
        /// Riseded up when the user removed image
        /// </summary>
        [DisplayName("Image Removed"), Category("Emulators Organizer"), Description("Riseded up when the user removed image")]
        public event EventHandler ImageRemoved;
        //next picture
        private void toolStripButton5_Click(object sender, EventArgs e)
        {
            if (_rom == null)
                return;
            if (!_IsCovers)//Snapshots
            {
                if (_rom.Snapshots != null)
                {
                    SelectedIndex++;
                    if (SelectedIndex > _rom.Snapshots.Count - 1)
                        SelectedIndex = 0;
                    ShowImage();
                }
            }
            else
            {
                if (_rom.Covers != null)
                {
                    SelectedIndex++;
                    if (SelectedIndex > _rom.Covers.Count - 1)
                        SelectedIndex = 0;
                    ShowImage();
                }
            }
        }
        //previous
        private void toolStripButton4_Click(object sender, EventArgs e)
        {
            if (_rom == null)
                return;
            if (!_IsCovers)//Snapshots
            {
                if (_rom.Snapshots != null)
                {
                    SelectedIndex--;
                    if (SelectedIndex < 0)
                        SelectedIndex = _rom.Snapshots.Count - 1;
                    ShowImage();
                }
            }
            else
            {
                if (_rom.Covers != null)
                {
                    SelectedIndex--;
                    if (SelectedIndex < 0)
                        SelectedIndex = _rom.Covers.Count - 1;
                    ShowImage();
                }
            }
        }
        //add images
        private void toolStripButton1_Click(object sender, EventArgs e)
        {
            if (_rom == null)
                return;
            OpenFileDialog op = new OpenFileDialog();
            op.Title = "Add image";
            op.Filter = "Supported image types (*.jpg;*.png;*.bmp;*.gif;*.jpeg;*.tiff;*.tga)|*.jpg;*.png;*.bmp;*.gif;*.jpeg;*.tif;*.tiff;*.tga";
            op.Multiselect = true;
            if (op.ShowDialog(this) == DialogResult.OK)
            {
                if (_IsCovers)
                {
                    if (_rom.Covers == null)
                        _rom.Covers = new List<string>();
                    foreach (string file in op.FileNames)
                    {
                        bool found = false;
                        foreach (string img in _rom.Covers)
                        {
                            if (Utilities.GetFullPath(img) == file)
                            { found = true; break; }
                        }
                        if (!found)
                        {
                            string Dir = file;
                            if (Path.GetDirectoryName(Dir).Length >= Application.StartupPath.Length)
                            {
                                if (Path.GetDirectoryName(Dir).Substring(0, Application.StartupPath.Length) == Application.StartupPath)
                                {
                                    Dir = "." + Dir.Substring(Application.StartupPath.Length);
                                }
                            }
                            _rom.Covers.Add(Dir);
                        }
                    }
                    SelectedIndex = _rom.Covers.Count - 1;
                    ShowImage();
                    if (ImageAdded != null)
                        ImageAdded(sender, e);
                }
                else
                {
                    if (_rom.Snapshots == null)
                        _rom.Snapshots = new List<string>();
                    foreach (string file in op.FileNames)
                    {
                        bool found = false;
                        foreach (string img in _rom.Snapshots)
                        {
                            if (Utilities.GetFullPath(img) == file)
                            { found = true; break; }
                        }
                        if (!found)
                        {
                            string Dir = file;
                            if (Path.GetDirectoryName(Dir).Length >= Application.StartupPath.Length)
                            {
                                if (Path.GetDirectoryName(Dir).Substring(0, Application.StartupPath.Length) == Application.StartupPath)
                                {
                                    Dir = "." + Dir.Substring(Application.StartupPath.Length);
                                }
                            }
                            _rom.Snapshots.Add(Dir);
                        }
                    }
                    SelectedIndex = _rom.Snapshots.Count - 1;
                    ShowImage();
                    if (ImageAdded != null)
                        ImageAdded(sender, e);
                }
            }
        }
        //remove
        private void toolStripButton2_Click(object sender, EventArgs e)
        {
            if (_rom == null)
                return;
            if (_IsCovers)
            {
                if (_rom.Covers != null)
                {
                    if (_rom.Covers.Count > 0)
                    {
                        if (MessageBox.Show("Are you sure ?", "Remove cover", MessageBoxButtons.YesNo, MessageBoxIcon.Question) == DialogResult.Yes)
                        {
                            _rom.Covers.RemoveAt(SelectedIndex);
                            SelectedIndex = 0;
                            ShowImage();
                            if (ImageRemoved != null)
                                ImageRemoved(sender, e);
                        }
                    }
                }
            }
            else
            {
                if (_rom.Snapshots != null)
                {
                    if (_rom.Snapshots.Count > 0)
                    {
                        if (MessageBox.Show("Are you sure ?", "Remove snapshot", MessageBoxButtons.YesNo, MessageBoxIcon.Question) == DialogResult.Yes)
                        {
                            _rom.Snapshots.RemoveAt(SelectedIndex);
                            SelectedIndex = 0;
                            ShowImage();
                            if (ImageRemoved != null)
                                ImageRemoved(sender, e);
                        }
                    }
                }
            }
        }
        //real remove
        private void toolStripButton3_Click(object sender, EventArgs e)
        {
            if (_rom == null)
                return;
            if (_IsCovers)
            {
                if (_rom.Covers != null)
                {
                    if (_rom.Covers.Count > 0)
                    {
                        if (MessageBox.Show("Are you sure ?\n\nWARNING: image will be removed from local disk", "Remove cover", MessageBoxButtons.YesNo, MessageBoxIcon.Question) == DialogResult.Yes)
                        {
                            try
                            {
                                pictureBox1.Visible = false;
                                if (pictureBox1.Image != null)
                                    pictureBox1.Image.Dispose();
                                if (CurrentImage != null)
                                    CurrentImage.Dispose();
                                pictureBox1.Image = null;
                                File.Delete(Utilities.GetFullPath(_rom.Covers[SelectedIndex]));
                            }
                            catch
                            {
                                MessageBox.Show("Unable to remove from disk !!");
                            }
                            _rom.Covers.RemoveAt(SelectedIndex);
                            SelectedIndex = 0;
                            ShowImage();
                            if (ImageRemoved != null)
                                ImageRemoved(sender, e);
                        }
                    }
                }
            }
            else
            {
                if (_rom.Snapshots != null)
                {
                    if (_rom.Snapshots.Count > 0)
                    {
                        if (MessageBox.Show("Are you sure ?\n\nWARNING: image will be removed from local disk", "Remove snapshot", MessageBoxButtons.YesNo, MessageBoxIcon.Question) == DialogResult.Yes)
                        {
                            try
                            {
                                File.Delete(Utilities.GetFullPath(_rom.Snapshots[SelectedIndex]));
                            }
                            catch
                            {
                                MessageBox.Show("Unable to remove from disk !!");
                            }
                            _rom.Snapshots.RemoveAt(SelectedIndex);
                            SelectedIndex = 0;
                            ShowImage();
                            if (ImageRemoved != null)
                                ImageRemoved(sender, e);
                        }
                    }
                }
            }
        }
        //view
        private void toolStripButton6_Click(object sender, EventArgs e)
        {
            if (_rom == null)
                return;
            if (_IsCovers)
            {
                if (_rom.Covers != null)
                {
                    if (_rom.Covers.Count > 0)
                    {
                        try
                        {
                            Process.Start(Utilities.GetFullPath(_rom.Covers[SelectedIndex]));
                        }
                        catch { }
                    }
                }
            }
            else
            {
                if (_rom.Snapshots != null)
                {
                    if (_rom.Snapshots.Count > 0)
                    {
                        try
                        {
                            Process.Start(Utilities.GetFullPath(_rom.Snapshots[SelectedIndex]));
                        }
                        catch { }
                    }
                }
            }
        }
        private void pictureBox1_MouseDoubleClick(object sender, MouseEventArgs e)
        {
            toolStripButton6_Click(this, null);
        }
        private void trackBar1_Scroll(object sender, EventArgs e)
        {
            if (CurrentImage != null)
            {
                pictureBox1.SizeMode = PictureBoxSizeMode.AutoSize;
                if (checkBox1.Checked)
                {
                    if (original_w + trackBar1.Value > 0 & original_h + trackBar1.Value > 0)
                        pictureBox1.Image = CurrentImage.GetThumbnailImage(original_w + trackBar1.Value, original_h + trackBar1.Value, null, IntPtr.Zero);
                }
                else
                {
                    if (trackBar1.Value > 0)
                        pictureBox1.Image = CurrentImage.GetThumbnailImage(trackBar1.Value, trackBar1.Value, null, IntPtr.Zero);

                }
                SetPictureBoxLocation();
            }
        }
        private void button1_Click(object sender, EventArgs e)
        {
            if (CurrentImage != null)
            {
                pictureBox1.SizeMode = PictureBoxSizeMode.AutoSize;
                pictureBox1.Image = CurrentImage;
                SetPictureBoxLocation(); trackBar1.Value = 100;
            }
        }
        //stretch
        private void button2_Click(object sender, EventArgs e)
        {
            try
            {
                if (_rom != null)
                {
                    //_StreatchByDefault = true;
                    // ShowImage();
                    //_StreatchByDefault = false;
                    pictureBox1.Image = null;
                    if (!_IsCovers)//Snapshots
                    {
                        if (_rom.Snapshots != null)
                        {
                            if (_rom.Snapshots.Count > 0)
                            {
                                try
                                {
                                    Stream str = new FileStream(Utilities.GetFullPath(_rom.Snapshots[SelectedIndex]), FileMode.Open, FileAccess.Read);
                                    byte[] buff = new byte[str.Length];
                                    str.Read(buff, 0, (int)str.Length);
                                    str.Dispose();
                                    str.Close();
                                    str = null;

                                    MemoryStream stream = new MemoryStream(buff);
                                    CurrentImage = new Bitmap(stream);
                                    //stream.Close();

                                    trackBar1.Value = 100;
                                    pictureBox1.Image = CurrentImage;
                                }
                                catch
                                {
                                    trackBar1.Value = 100; CurrentImage = null;
                                    pictureBox1.Image = null;
                                    Graphics GR = pictureBox1.CreateGraphics();
                                    GR.DrawString("Preview is not available", TextOfImages.Font, new SolidBrush(Color.Black), new PointF(2, 2));
                                }
                                TextOfImages.Text = (SelectedIndex + 1).ToString() + " of " + _rom.Snapshots.Count;
                            }
                            else
                            {
                                CurrentImage = null;
                                pictureBox1.Image = null;
                                TextOfImages.Text = "N/A";
                            }
                        }
                        else
                        {
                            pictureBox1.Image = null; CurrentImage = null;
                            TextOfImages.Text = "N/A";
                        }
                    }
                    else//covers
                    {
                        if (_rom.Covers != null)
                        {
                            if (_rom.Covers.Count > 0)
                            {
                                try
                                {
                                    Stream str = new FileStream(Utilities.GetFullPath(_rom.Covers[SelectedIndex]), FileMode.Open, FileAccess.Read);
                                    byte[] buff = new byte[str.Length];
                                    str.Read(buff, 0, (int)str.Length);
                                    str.Dispose();
                                    str.Close();
                                    str = null;

                                    MemoryStream stream = new MemoryStream(buff);
                                    CurrentImage = new Bitmap(stream);
                                    //stream.Close();

                                    trackBar1.Value = 100;
                                    pictureBox1.Image = CurrentImage;
                                }
                                catch
                                {
                                    pictureBox1.Image = null; CurrentImage = null;
                                    Graphics GR = pictureBox1.CreateGraphics();
                                    GR.DrawString("Preview is not available", TextOfImages.Font, new SolidBrush(Color.Black), new PointF(2, 2));
                                }
                                TextOfImages.Text = (SelectedIndex + 1).ToString() + " of " + _rom.Covers.Count;
                            }
                            else
                            {
                                pictureBox1.Image = null; CurrentImage = null;
                                TextOfImages.Text = "N/A";
                            }
                        }
                        else
                        {
                            pictureBox1.Image = null; CurrentImage = null;
                            TextOfImages.Text = "N/A";
                        }
                    }
                    //FixSize();
                    if (CurrentImage != null)
                    {
                        pictureBox1.Visible = true;
                        panel2.BackgroundImage = null;
                        pictureBox1.Image = CurrentImage;
                        pictureBox1.SizeMode = PictureBoxSizeMode.StretchImage;
                        pictureBox1.Location = new Point(0, 0);
                        pictureBox1.Size = new Size(panel2.Width, panel2.Height);
                    }
                    else
                    {
                        pictureBox1.Visible = false;
                        panel2.BackgroundImage = Properties.Resources.EmulatorsOrganizer;
                    }
                    SetPictureBoxLocation();
                }
            }
            catch { }
        }
        private void toolStripButton7_Click(object sender, EventArgs e)
        {
            try
            {
                if (_IsCovers)
                    Process.Start("explorer.exe", @"/select, " + Utilities.GetFullPath(_rom.Covers[SelectedIndex]));
                else
                    Process.Start("explorer.exe", @"/select, " + Utilities.GetFullPath(_rom.Snapshots[SelectedIndex]));
            }
            catch { }
        }

        private void pictureBox1_DragOver(object sender, DragEventArgs e)
        {
            if (e.Data.GetDataPresent(DataFormats.FileDrop))
            {
                if ((e.AllowedEffect & DragDropEffects.Copy) == DragDropEffects.Copy && (_rom != null))
                {
                    e.Effect = DragDropEffects.Copy;
                }
                else
                {
                    e.Effect = DragDropEffects.None;
                }
            }
        }

        private void pictureBox1_DragDrop(object sender, DragEventArgs e)
        {
            if (_rom == null)
                return;
            if (e.Effect== DragDropEffects.None)
                return;
            List<string> DragedFiles = new List<string>();
            DragedFiles.AddRange((string[])e.Data.GetData(DataFormats.FileDrop));
            if (DragedFiles.Count == 1)
            {
                if (Utilities.GetFullPath(currentImagePath) == DragedFiles[0])
                    return;
            }
            string[] extensions = new string[] { ".jpg", ".png", ".bmp", ".gif", ".jpeg", ".tif", ".tiff", ".tga" };
            bool clearOld = MessageBox.Show("Do you want to clear old collection first ?", "Drop Images",
                MessageBoxButtons.YesNo, MessageBoxIcon.Question) == DialogResult.Yes;
            if (_IsCovers)
            {
                if (_rom.Covers == null)
                    _rom.Covers = new List<string>();
                if (clearOld)
                    _rom.Covers = new List<string>();
                foreach (string file in DragedFiles)
                {
                    if (!extensions.Contains(Path.GetExtension(file).ToLower()))
                        continue;
                    bool found = false;
                    foreach (string img in _rom.Covers)
                    {
                        if (Utilities.GetFullPath(img) == file)
                        { found = true; break; }
                    }
                    if (!found)
                    {
                        string Dir = file;
                        if (Path.GetDirectoryName(Dir).Length >= Application.StartupPath.Length)
                        {
                            if (Path.GetDirectoryName(Dir).Substring(0, Application.StartupPath.Length) == Application.StartupPath)
                            {
                                Dir = "." + Dir.Substring(Application.StartupPath.Length);
                            }
                        }
                        _rom.Covers.Add(Dir);
                    }
                }
                SelectedIndex = _rom.Covers.Count - 1;
                ShowImage();
                if (ImageAdded != null)
                    ImageAdded(sender, e);
            
            }
            else
            {
                if (_rom.Snapshots == null)
                    _rom.Snapshots = new List<string>();
                if (clearOld)
                    _rom.Snapshots = new List<string>();
                foreach (string file in DragedFiles)
                {
                    if (!extensions.Contains(Path.GetExtension(file).ToLower()))
                        continue;
                    bool found = false;
                    foreach (string img in _rom.Snapshots)
                    {
                        if (Utilities.GetFullPath(img) == file)
                        { found = true; break; }
                    }
                    if (!found)
                    {
                        string Dir = file;
                        if (Path.GetDirectoryName(Dir).Length >= Application.StartupPath.Length)
                        {
                            if (Path.GetDirectoryName(Dir).Substring(0, Application.StartupPath.Length) == Application.StartupPath)
                            {
                                Dir = "." + Dir.Substring(Application.StartupPath.Length);
                            }
                        }
                        _rom.Snapshots.Add(Dir);
                    }
                }
                SelectedIndex = _rom.Snapshots.Count - 1;
                ShowImage();
                if (ImageAdded != null)
                    ImageAdded(sender, e);
            }
            e.Effect = DragDropEffects.None;
        }

        private void panel2_DragLeave(object sender, EventArgs e)
        {

        }

        private void pictureBox1_MouseDown(object sender, MouseEventArgs e)
        {
            if (e.Button == System.Windows.Forms.MouseButtons.Left)
                DoDragDrop(new DataObject(DataFormats.FileDrop, new string[] { Utilities.GetFullPath(currentImagePath) }), DragDropEffects.Copy | DragDropEffects.Move);
        }
    }
}
