﻿/*  
     This file is part of Emulators Organizer
    A program that organize emulators and roms.
   
    Copyright (C) 2009 - 2012  Ali Hadid, programmed by Ala Hadid

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Net;
using System.IO;
using System.Windows.Forms;
using AHD.Utilities;
namespace EmulatorsOrganizer.Controls
{
    public partial class Frm_MobyGames : Form
    {
        MobyGamesGame[] games;
        public Frm_MobyGames(string romName)
        {
            InitializeComponent();
            textBox1.Text = romName;
            Search();
        }
        void Search()
        {
            if (textBox1.Text.Length == 0)
            {
                MessageBox.Show("Please enter rom name to search");
                return;
            }
            listView1.Items.Clear();
            games = MobyGamesSearcher.GetLinks(textBox1.Text);
            foreach (MobyGamesGame game in games)
            {
                listView1.Items.Add(game.Link.Replace("http://www.mobygames.com/game", ""));
            }
        }
        public string RTF
        {
            get
            {
                return richTextBox1.Rtf;
            }
        }
        private void button1_Click(object sender, EventArgs e)
        {
            Search();
        }
        private void richTextBox1_TextChanged(object sender, EventArgs e)
        {
            button2.Enabled = richTextBox1.Text.Length > 0;
        }
        private void button2_Click(object sender, EventArgs e)
        {
            this.DialogResult = System.Windows.Forms.DialogResult.OK;
            Close();
        }
        private void button3_Click(object sender, EventArgs e)
        {
            this.DialogResult = System.Windows.Forms.DialogResult.Cancel;
            Close();
        }
        private void listView1_SelectedIndexChanged(object sender, EventArgs e)
        {
            if (listView1.SelectedItems.Count == 1)
            {
                richTextBox1.Clear();
                richTextBox1.SelectionStart = 0;
                //insert picture
                WebClient cl = new WebClient();
                byte[] data = cl.DownloadData(MobyGamesSearcher.FetchCoverLink(games[listView1.SelectedItems[0].Index].Link));
                Stream str = new MemoryStream(data);
                Clipboard.SetImage(Image.FromStream(new MemoryStream(data)));
                str.Dispose();
                str.Close();
                richTextBox1.Paste();

                //get game name
                richTextBox1.SelectionFont = new System.Drawing.Font("Arial", 8, FontStyle.Bold);
                string[] textLines = MobyGamesSearcher.FetchInfo(games[listView1.SelectedItems[0].Index].Link).Split(new char[] { '\n' });
                richTextBox1.SelectedText = "\n" + textLines[0] + "\n";
                for (int i = 1; i < textLines.Length; i++)
                {
                    if (textLines[i].Length == 0 && textLines[i] == "  ")
                        continue;
                    if (textLines[i].Contains("Published by"))
                    {
                        richTextBox1.SelectionFont = new System.Drawing.Font("Arial", 8, FontStyle.Bold);
                        richTextBox1.SelectedText = "Published by\n";
                        richTextBox1.SelectionFont = new System.Drawing.Font("Arial", 8, FontStyle.Regular);
                        richTextBox1.SelectedText = textLines[i].Replace("Published by", "") + "\n";
                    }
                    else if (textLines[i].Contains("Developed by"))
                    {
                        richTextBox1.SelectionFont = new System.Drawing.Font("Arial", 8, FontStyle.Bold);
                        richTextBox1.SelectedText = "Developed by\n";
                        richTextBox1.SelectionFont = new System.Drawing.Font("Arial", 8, FontStyle.Regular);
                        richTextBox1.SelectedText = textLines[i].Replace("Developed by", "") + "\n";
                    }
                    else if (textLines[i].Contains("Released"))
                    {
                        richTextBox1.SelectionFont = new System.Drawing.Font("Arial", 8, FontStyle.Bold);
                        richTextBox1.SelectedText = "Released\n";
                        richTextBox1.SelectionFont = new System.Drawing.Font("Arial", 8, FontStyle.Regular);
                        richTextBox1.SelectedText = textLines[i].Replace("Released", "") + "\n";
                    }
                    else if (textLines[i].Contains("Platform"))
                    {
                        richTextBox1.SelectionFont = new System.Drawing.Font("Arial", 8, FontStyle.Bold);
                        richTextBox1.SelectedText = "Platform\n";
                        richTextBox1.SelectionFont = new System.Drawing.Font("Arial", 8, FontStyle.Regular);
                        string platforms = "";
                        while (textLines[i] != "")
                        {
                            if (textLines[i] != "Platform")
                                platforms += textLines[i] + ", ";
                            i++;
                        }
                        richTextBox1.SelectedText = platforms + "\n";
                    }
                    else if (textLines[i].Contains("Genre"))
                    {
                        richTextBox1.SelectionFont = new System.Drawing.Font("Arial", 8, FontStyle.Bold);
                        richTextBox1.SelectedText = "Genre\n";
                        richTextBox1.SelectionFont = new System.Drawing.Font("Arial", 8, FontStyle.Regular);
                        string genres = "";
                        while (textLines[i] != "")
                        {
                            if (textLines[i] != "Genre")
                                genres += textLines[i] + ", ";
                            i++;
                        }
                        richTextBox1.SelectedText = genres + "\n";
                    }
                    else if (textLines[i].Contains("Description"))
                    {
                        richTextBox1.SelectionFont = new System.Drawing.Font("Arial", 8, FontStyle.Bold);
                        richTextBox1.SelectedText = "Description\n";
                        richTextBox1.SelectionFont = new System.Drawing.Font("Arial", 8, FontStyle.Regular);
                        string desc = "";
                        while (textLines[i] != "")
                        {
                            if (textLines[i] != "Description")
                                desc += textLines[i] + "\n";
                            i++;
                        }
                        richTextBox1.SelectedText = desc;
                    }
                    else
                    {
                        richTextBox1.SelectionFont = new System.Drawing.Font("Arial", 8, FontStyle.Regular);
                        richTextBox1.SelectedText = textLines[i] + "\n";
                    }
                }
            }
        }
    }
}