﻿/*  
     This file is part of Emulators Organizer
    A program that organize emulators and roms.
   
    Copyright (C) 2009 - 2012  Ali Hadid, programmed by Ala Hadid

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Linq;
using System.Text;
using System.IO;
using System.Diagnostics;
using System.Windows.Forms;
using AHD.Emulators_Organizer.Base;
using AHD.Utilities;

namespace EmulatorsOrganizer.Controls
{
    public partial class InfoEditor : UserControl
    {
        bool _IsHistory = false;
        string _RomName = "";
        string _InfoPath = "";//folder path
        string _HistoryPath = "";//folder path

        string _rtfPath = "";
        string _txtPath = "";

        /// <summary>
        /// Get or set if the editor should be for history, false means info
        /// </summary>
        public bool IsHistory
        { get { return _IsHistory; } set { _IsHistory = value; } }
        public string InfoFolderPath
        {
            get { return _InfoPath; }
            set
            {
                _InfoPath = value;
                try
                {
                    Directory.CreateDirectory(_InfoPath);
                }
                catch { }
            }
        }
        public string HistoryFolderPath
        {
            get { return _HistoryPath; }
            set
            {
                _HistoryPath = value; try
                {
                    Directory.CreateDirectory(_HistoryPath);
                }
                catch { }
            }
        }
        /// <summary>
        /// Rom name accurding to ROM FILE, without extension.
        /// </summary>
        public string RomName
        {
            get { return _RomName; }
            set
            {
                _RomName = value; richTextBox1.Text = "";
                if (value != null)
                {
                    this.Enabled = true;
                    if (!_IsHistory)
                    {
                        _rtfPath = _InfoPath + "\\" + _RomName + ".rtf";
                        _txtPath = _InfoPath + "\\" + _RomName + ".txt";
                    }
                    else
                    {
                        _rtfPath = _HistoryPath + "\\" + _RomName + ".rtf";
                        _txtPath = _HistoryPath + "\\" + _RomName + ".txt";
                    }
                    if (File.Exists(_rtfPath))
                        toolStripComboBox1.SelectedItem = "RTF";
                    else
                        toolStripComboBox1.SelectedItem = "TXT";
                    RefreshText();
                }
                else
                {
                    this.Enabled = false;
                    richTextBox1.Text = "";
                }
            }
        }
        public InfoEditor()
        {
            InitializeComponent();
            toolStripComboBox1.SelectedIndex = 0;
        }
        /// <summary>
        /// Refresh the text
        /// </summary>
        public void RefreshText()
        {
            if (!_IsHistory)
            {
                if (!Directory.Exists(_InfoPath))
                {
                    //MessageBox.Show("The info folder for this console isn't exist, please specify an info folder for this console via Console properties window. Select the console then press F4");
                    richTextBox1.Text = ""; return;
                }
            }
            else
            {
                if (!Directory.Exists(_HistoryPath))
                {
                    //MessageBox.Show("The history folder for this console isn't exist, please specify a history folder for this console via Console properties window. Select the console then press F4");
                    richTextBox1.Text = ""; return;
                }
            }
            try
            {
                switch (toolStripComboBox1.SelectedItem.ToString().ToLower())
                {
                    case "rtf": richTextBox1.LoadFile(_rtfPath); break;
                    case "txt": richTextBox1.Lines = File.ReadAllLines(_txtPath); break;
                }
            }
            catch { }
        }

        private void toolStripButton1_Click(object sender, EventArgs e)
        {
            RefreshText();
        }

        private void toolStripComboBox1_SelectedIndexChanged(object sender, EventArgs e)
        {
            richTextBox1.Text = "";
            RefreshText();
        }
        //delete
        private void toolStripButton2_Click(object sender, EventArgs e)
        {
            switch (toolStripComboBox1.SelectedItem.ToString().ToLower())
            {
                case "rtf":
                    if (File.Exists(_rtfPath))
                    {
                        if (MessageBox.Show("Are you sure ?\n\nThis cannot be undone", "Delete", MessageBoxButtons.YesNo, MessageBoxIcon.Question) == DialogResult.Yes)
                        {
                            try
                            {
                                File.Delete(_rtfPath);
                                richTextBox1.Text = "";
                            }
                            catch
                            {
                                MessageBox.Show("Can't delete the file !!");
                            }
                        }
                    }
                    break;
                case "txt": if (File.Exists(_txtPath))
                    {
                        if (MessageBox.Show("Are you sure ?\n\nThis cannot be undone", "Delete", MessageBoxButtons.YesNo, MessageBoxIcon.Question) == DialogResult.Yes)
                        {
                            try
                            {
                                File.Delete(_txtPath);
                                richTextBox1.Text = "";
                            }
                            catch
                            {
                                MessageBox.Show("Can't delete the file !!");
                            }
                        }
                    }
                    break;
            }
        }
        //save
        private void toolStripButton4_Click(object sender, EventArgs e)
        {
            if (!_IsHistory)
            {
                if (!Directory.Exists(_InfoPath))
                {
                    MessageBox.Show("The info folder for this console isn't exist, please specify an info folder for this console via Console properties window. Select the console then press F4");
                    return;
                }
            }
            else
            {
                if (!Directory.Exists(_HistoryPath))
                {
                    MessageBox.Show("The history folder for this console isn't exist, please specify a history folder for this console via Console properties window. Select the console then press F4");
                    return;
                }
            }
            switch (toolStripComboBox1.SelectedItem.ToString().ToLower())
            {
                case "rtf": richTextBox1.SaveFile(_rtfPath); break;
                case "txt": File.WriteAllLines(_txtPath, richTextBox1.Lines); break;
            }
        }

        private void toolStripButton3_Click(object sender, EventArgs e)
        {
            try
            {
                switch (toolStripComboBox1.SelectedItem.ToString().ToLower())
                {
                    case "rtf": Process.Start(_rtfPath); break;
                    case "txt": Process.Start(_txtPath); break;
                }
            }
            catch { }
        }

        public void CopyToClipBoard()
        {
            richTextBox1.Copy();
        }
        public void CutToClipBoard()
        {
            richTextBox1.Cut();
        }
        public void PasteFromClipBoard()
        {
            richTextBox1.Paste();
        }

        private void cutToolStripMenuItem_Click(object sender, EventArgs e)
        {
            CutToClipBoard();
        }

        private void copyToolStripMenuItem_Click(object sender, EventArgs e)
        {
            CopyToClipBoard();
        }

        private void pasteToolStripMenuItem_Click(object sender, EventArgs e)
        {
            PasteFromClipBoard();
        }

        private void selectAllToolStripMenuItem_Click(object sender, EventArgs e)
        {
            richTextBox1.SelectAll();
        }

        private void toolStripButton5_Click(object sender, EventArgs e)
        {
            try
            {
                switch (toolStripComboBox1.SelectedItem.ToString().ToLower())
                {
                    case "rtf":
                        if (File.Exists(Utilities.GetFullPath(_rtfPath)))
                            Process.Start("explorer.exe", @"/select, " + Utilities.GetFullPath(_rtfPath));
                        break;
                    case "txt":
                        if (File.Exists(Utilities.GetFullPath(_txtPath)))
                            Process.Start("explorer.exe", @"/select, " + Utilities.GetFullPath(_txtPath));
                        break;
                }
            }
            catch { }
        }

        private void mobyGamescomToolStripMenuItem_Click(object sender, EventArgs e)
        {
            Frm_MobyGames frm = new Frm_MobyGames(_RomName);
            richTextBox1.Clear();
            if (frm.ShowDialog(this) == DialogResult.OK)
            {
                toolStripComboBox1.SelectedItem = "RTF";
                richTextBox1.Clear();
                richTextBox1.Rtf = frm.RTF;
                //save
                toolStripButton4_Click(sender, e);
            }
        }
    }
}
