﻿/*  
     This file is part of Emulators Organizer
    A program that organize emulators and roms.
   
    Copyright (C) 2009 - 2012  Ali Hadid, programmed by Ala Hadid

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Linq;
using System.Text;
using System.IO;
using System.Windows.Forms;
using AHD.Emulators_Organizer.Base;
using AHD.Utilities;

namespace EmulatorsOrganizer.Controls
{
    public partial class RomStatus : UserControl
    {
        Rom _rom;
        bool _ShowSnap = true;
        public Rom Rom
        { get { return _rom; } set { _rom = value; RefreshRom(); } }
        public bool ShowSnapshot
        { get { return _ShowSnap; } set { _ShowSnap = value; } }
        public void RefreshRom()
        {
            pictureBox1.Image = Properties.Resources.EmulatorsOrganizer;
            if (_rom == null)
            {
                label2_name.Text = "";
                label3_path.Text = "";
                label1_played.Text = "";
                label_year.Text = "";
                rating1.rating = 0;
                if (pictureBox1.Image != null)
                    pictureBox1.Image.Dispose();
                pictureBox1.Image = Properties.Resources.EmulatorsOrganizer;
                this.Enabled = false;
                return;
            }
            this.Enabled = true;
            label2_name.Text = _rom.Name;
            if (!_rom.IsURL)
                label3_path.Text = Utilities.GetFullPath(_rom.Path);
            else
                label3_path.Text = _rom.URL;
            rating1.rating = _rom.Rating;
            label1_played.Text = "Played " + _rom.PlayedTimes + " time(s)";
            label_year.Text = "Year : " + _rom.Year;
            if (_ShowSnap)
            {
                if (_rom.Snapshots.Count > 0)
                    if (File.Exists(_rom.Snapshots[0]))
                    {
                        try
                        {
                            //pictureBox1.Image = Image.FromFile(Utilities.GetFullPath(_rom.Snapshots[0]));
                            Stream str = new FileStream(Utilities.GetFullPath(_rom.Snapshots[0]), FileMode.Open, FileAccess.Read);
                            byte[] buff = new byte[str.Length];
                            str.Read(buff, 0, (int)str.Length);
                            str.Dispose();
                            str.Close();
                            str = null;

                            MemoryStream stream = new MemoryStream(buff);
                            Bitmap CurrentImage = new Bitmap(stream);
                            //stream.Close();

                            pictureBox1.Image = CurrentImage;
                        }
                        catch
                        {
                            if (pictureBox1.Image != null)
                                pictureBox1.Image.Dispose(); pictureBox1.Image = Properties.Resources.EmulatorsOrganizer;
                        }
                    }
            }
            else
            {
                if (_rom.Covers.Count > 0)
                    if (File.Exists(_rom.Covers[0]))
                    {
                        try
                        {
                            //pictureBox1.Image = Image.FromFile(Utilities.GetFullPath(_rom.Covers[0]));
                            Stream str = new FileStream(Utilities.GetFullPath(_rom.Covers[0]), FileMode.Open, FileAccess.Read);
                            byte[] buff = new byte[str.Length];
                            str.Read(buff, 0, (int)str.Length);
                            str.Dispose();
                            str.Close();
                            str = null;

                            MemoryStream stream = new MemoryStream(buff);
                            Bitmap CurrentImage = new Bitmap(stream);
                            //stream.Close();

                            pictureBox1.Image = CurrentImage;
                        }
                        catch
                        {
                            if (pictureBox1.Image != null)
                                pictureBox1.Image.Dispose(); pictureBox1.Image = Properties.Resources.EmulatorsOrganizer;
                        }
                    }
            }
        }
        public RomStatus()
        {
            InitializeComponent();
        }

        private void rating1_RatingChanged(object sender, EventArgs e)
        {
            _rom.Rating = rating1.rating;
            if (RatingChanged != null)
                RatingChanged(this, null);
        }
        public event EventHandler RatingChanged;
    }
}
