﻿/*  
     This file is part of Emulators Organizer
    A program that organize emulators and roms.
   
    Copyright (C) 2009 - 2012  Ali Hadid, programmed by Ala Hadid

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Linq;
using System.Text;
using System.IO;
using System.Diagnostics;
using System.Windows.Forms;
using AHD.Emulators_Organizer.Base;
using AHD.Utilities;

namespace EmulatorsOrganizer.Controls
{
    public partial class cnt_ConfigurationFileEditor : UserControl
    {
        ConfigurationFile configFile;
        int ValueIndex = 0;
        public cnt_ConfigurationFileEditor()
        {
            InitializeComponent();
        }
        public ConfigurationFile ConfigFile
        {
            get { return configFile; }
            set
            {
                configFile = value;
                ReloadConfig();
            }
        }
        public void ReloadConfig()
        {
            listView1.Items.Clear();
            listView1.Groups.Clear();
            comboBox1.Items.Clear();
            comboBox1.Visible = false;

            if (configFile == null)
                return;   
            if (!File.Exists(Utilities.GetFullPath(configFile.FilePath)))
                return;
            configFile.Reload();
            ListViewGroup currentGroup = new ListViewGroup("");
            listView1.Groups.Add(currentGroup);
            //add values
            foreach (ConfigurationValue val in configFile.Values)
            {
                if (currentGroup.Header != val.Category)
                {
                    currentGroup = new ListViewGroup(val.Category);
                    listView1.Groups.Add(currentGroup);
                }
                ListViewItem item = new ListViewItem();
                item.Text = val.Name;
                item.SubItems.Add(val.Value);
                listView1.Items.Add(item);
                currentGroup.Items.Add(item);
            }
        }
        public void SaveConfigFile()
        {
            if (configFile == null)
                return;
            configFile.Save();
        }
        public void Clear()
        {
            listView1.Items.Clear();
            comboBox1.Visible = false;
        }
        public void ShowInWindowsEditor()
        {
            if (configFile == null)
                return;
            try 
            {
                Process.Start(Utilities.GetFullPath(configFile.FilePath));
            }
            catch { }
        }
        public void SaveAs()
        {
            if (configFile == null)
                return;
            if (!File.Exists(Utilities.GetFullPath(configFile.FilePath)))
                return;

            SaveFileDialog sav = new SaveFileDialog();
            sav.Filter = "(*" + Path.GetExtension(configFile.FilePath) + ")|*" + Path.GetExtension(configFile.FilePath);
            sav.FileName = Path.GetFileName(configFile.FilePath);
            if (sav.ShowDialog(this) == DialogResult.OK)
            {
                configFile.SaveAs(sav.FileName);
            }
        }

        private void listView1_SelectedIndexChanged(object sender, EventArgs e)
        {
            //save old value
            if (comboBox1.Visible)
            {
                if (!comboBox1.Items.Contains(comboBox1.Text))
                    comboBox1.Items.Add(comboBox1.Text);

                configFile.Values[ValueIndex].Values.Clear();
                foreach (string val in comboBox1.Items)
                    configFile.Values[ValueIndex].Values.Add(val);
     
                configFile.Values[ValueIndex].Value = comboBox1.Text;
                listView1.Items[ValueIndex].SubItems[1].Text = comboBox1.Text;
            }
            if (listView1.SelectedItems.Count == 1)
            {
                comboBox1.Location = listView1.SelectedItems[0].SubItems[1].Bounds.Location;
                comboBox1.Size = listView1.SelectedItems[0].SubItems[1].Bounds.Size;

                comboBox1.Items.Clear();
                ValueIndex = listView1.SelectedItems[0].Index;
                foreach (string val in configFile.Values[listView1.SelectedItems[0].Index].Values)
                    comboBox1.Items.Add(val);
                comboBox1.Text = listView1.SelectedItems[0].SubItems[1].Text;

                comboBox1.Visible = true;
            }
            else
                comboBox1.Visible = false;
        }

        private void comboBox1_KeyDown(object sender, KeyEventArgs e)
        {
            if (e.KeyCode == Keys.Delete)
            {
                if (comboBox1.Items.Contains(comboBox1.Text))
                {
                    comboBox1.Items.Remove(comboBox1.Text);
                    comboBox1.Text = "";
                }
            }
        }
    }
}
