﻿/*  
     This file is part of Emulators Organizer
    A program that organize emulators and roms.
   
    Copyright (C) 2009 - 2012  Ali Hadid, programmed by Ala Hadid

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.IO;
using System.Windows.Forms;
using AHD.Emulators_Organizer.Base;
using AHD.Utilities;

namespace EmulatorsOrganizer.Frms
{
    public partial class Frm_AddRom : Form
    {
        EmuConsole _console;
        public Frm_AddRom(EmuConsole console)
        {
            _console = console;
            InitializeComponent();
        }

        private void radioButton1_CheckedChanged(object sender, EventArgs e)
        {
            button1.Enabled = radioButton1.Checked;
            textBox2_url.Enabled = !radioButton1.Checked;
            textBox2_dFileName.Enabled = !radioButton1.Checked;
        }

        private void button3_Click(object sender, EventArgs e)
        {
            DialogResult = System.Windows.Forms.DialogResult.Cancel;
            Close();
        }

        private void button2_Click(object sender, EventArgs e)
        {
            if (textBox1.Text == "")
            {
                MessageBox.Show("Please enter rom name");
                return;
            }
            if (radioButton1.Checked)
            {
                if (textBox1_path.Text == "")
                {
                    MessageBox.Show("Please browse for a rom file");
                    return;
                }
                foreach (Rom rom in _console.Roms)
                {
                    if (rom.Path.ToLower() == textBox1_path.Text.ToLower())
                    {
                        if (MessageBox.Show(@"This rom is already exists under name """ + rom.Name + @"""" + "\nAdd this rom any way ?", "Rom exists", MessageBoxButtons.YesNo, MessageBoxIcon.Question) == System.Windows.Forms.DialogResult.No)
                        {
                            return;
                        }
                        break;
                    }
                }
                Rom newRom = new Rom();
                newRom.Name = textBox1.Text;
                newRom.RomSize = Utilities.GetFileSize(textBox1_path.Text);
                newRom.Path = Utilities.GetDotPath(textBox1_path.Text);
                _console.Roms.Add(newRom);
            }
            else
            {
                if (textBox2_url.Text == "")
                {
                    MessageBox.Show("Please enter rom file link");
                    return;
                }
                if (textBox2_dFileName.Text == "")
                {
                    MessageBox.Show("Please enter download rom file name !!");
                    return;
                }
                if (Path.GetExtension( textBox2_dFileName.Text)=="")
                {
                    MessageBox.Show("Please enter extenstion for the download rom file name");
                    return;
                }
                bool found = false;
                foreach (string ex in _console.Extensions)
                {
                    if (ex.ToLower() == Path.GetExtension(textBox2_dFileName.Text).ToLower())
                    {
                        found = true;
                        break;
                    }
                }
                if (!found)
                {
                    MessageBox.Show("This extenstion for the download rom file name is not supported by the console '"+_console.Name+"'");
                    return;
                }
                foreach (Rom rom in _console.Roms)
                {
                    if (rom.IsURL)
                        if (rom.URL.ToLower() == textBox2_url.Text.ToLower())
                        {
                            if (MessageBox.Show(@"This rom is already exists under name """ + rom.Name + @"""" + "\nAdd this rom any way ?", "Rom exists", MessageBoxButtons.YesNo, MessageBoxIcon.Question) == System.Windows.Forms.DialogResult.No)
                            {
                                return;
                            }
                            break;
                        }
                }
                Rom newRom = new Rom();
                newRom.IsURL = true;
                newRom.RomSize = "Not downloaded";
                newRom.Name = textBox1.Text;
                newRom.URL = textBox2_url.Text;
                newRom.DownloadFileName = textBox2_dFileName.Text;
                _console.Roms.Add(newRom);
            }
            DialogResult = System.Windows.Forms.DialogResult.OK;
            Close();
        }

        private void button1_Click(object sender, EventArgs e)
        {
            OpenFileDialog fil = new OpenFileDialog();
            fil.Title = "Add roms";
            string filter = _console.Name + " roms (";
            if (_console.Extensions.Count == 1)
            { filter += "*" + _console.Extensions[0]; }
            else
            {
                foreach (string ext in _console.Extensions)
                {
                    filter += "*" + ext;
                    if (_console.Extensions[_console.Extensions.Count - 1] != ext)
                    { filter += ","; }
                }
            }
            filter += ")|";
            foreach (string ext in _console.Extensions)
            {
                filter += "*" + ext + ";";
            }
            fil.Filter = filter;
            if (fil.ShowDialog(this) == DialogResult.OK)
            {
                textBox1_path.Text = fil.FileName;
            }
        }

        private void textBox2_url_Validated(object sender, EventArgs e)
        {
            try
            {
                string[] splited = textBox2_url.Text.Split(new char[] { '/' });
                textBox2_dFileName.Text = splited[splited.Length - 1];
                textBox2_dFileName.Text = textBox2_dFileName.Text.Replace("%20", " ");
            }
            catch { }
        }
    }
}
