﻿/*  
     This file is part of Emulators Organizer
    A program that organize emulators and roms.
   
    Copyright (C) 2009 - 2012  Ali Hadid, programmed by Ala Hadid

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.IO;
using System.Windows.Forms;
using System.Security.Cryptography;
using AHD.Emulators_Organizer.Base;
using AHD.Utilities;

namespace EmulatorsOrganizer.Frms
{
    public partial class Frm_GetNamesFromDatabase : Form
    {
        public Frm_GetNamesFromDatabase(EmuConsole console)
        {
            this.console = console;
            InitializeComponent();
        }
        EmuConsole console;
        IDatabaseFile fbFile;
        List<string> Log = new List<string>();
        //browse
        private void button1_Click(object sender, EventArgs e)
        {
            OpenFileDialog op = new OpenFileDialog();
            op.Filter = DatabaseManager.GetFilter();
            op.Title = "Open database file";
            if (op.ShowDialog(this) == System.Windows.Forms.DialogResult.OK)
            {
                textBox1.Text = op.FileName;
                fbFile = DatabaseManager.GetFromExtension(Path.GetExtension(textBox1.Text));
                fbFile.Progress += new EventHandler<ProgressArg>(fbFile_Progress);

                radioButton_crc.Enabled = fbFile.IsSupportCRC;
                radioButton_md5.Enabled = fbFile.IsSupportMD5;
                radioButton_sha1.Enabled = fbFile.IsSupportSHA1;
            }
        }
        //Start
        private void button2_Click(object sender, EventArgs e)
        {
            if (!File.Exists(textBox1.Text))
            {
                MessageBox.Show("Browse for database file first !!");
                return;
            }
            if (radioButton_crc.Checked & !fbFile.IsSupportCRC)
            {
                MessageBox.Show("This database file doesn't support CRC !! please choose another option");
                return;
            }
            if (radioButton_md5.Checked & !fbFile.IsSupportMD5)
            {
                MessageBox.Show("This database file doesn't support MD5 !! please choose another option");
                return;
            }
            if (radioButton_sha1.Checked & !fbFile.IsSupportSHA1)
            {
                MessageBox.Show("This database file doesn't support SHA1 !! please choose another option");
                return;
            }
            int romsFound = 0;
            groupBox1.Enabled = groupBox2.Enabled = button1.Enabled = button2.Enabled = button3.Enabled = false;

            if (fbFile.OpenFile(textBox1.Text))
            {
                List<string> foundRoms = new List<string>();
                List<string> missedRoms = new List<string>();
                Log.Add("GET ROM NAMES FROM DATABASE");
                Log.Add("Started operation at " + DateTime.Now.ToShortDateString() + " " + DateTime.Now.ToShortTimeString());
                Log.Add("");
                label1.Text = "Creating roms list ....";
                progressBar1.Value = 0;
                Application.DoEvents();
                //2 create a buffer for the console roms... things will go faster
                List<DatabaseRom> virtualRoms = new List<DatabaseRom>();
                for (int i = 0; i < console.Roms.Count; i++)
                {
                    DatabaseRom vRom = new DatabaseRom();
                    vRom.Name = console.Roms[i].Name;

                    if (radioButton_sha1.Checked)
                        vRom.SHA1 = fbFile.CalculateSHA1(Utilities.GetFullPath(console.Roms[i].Path));
                    if (radioButton_md5.Checked)
                        vRom.MD5 = fbFile.CalculateMD5(Utilities.GetFullPath(console.Roms[i].Path));
                    if (radioButton_crc.Checked)
                        vRom.CRC = fbFile.CalculateCRC(Utilities.GetFullPath(console.Roms[i].Path));

                    virtualRoms.Add(vRom);
                    progressBar1.Value = (i * 100) / console.Roms.Count;
                    label1.Text = "Creating roms list (" + progressBar1.Value + " %)";
                    Application.DoEvents();
                }
                //3 search for a rom that match this database rom
                label1.Text = "Applying names that found ....";

                progressBar1.Value = 0;
                Application.DoEvents();
                int realJ = 0;
                int realS = virtualRoms.Count;
                for (int j = 0; j < virtualRoms.Count; j++)
                {
                    bool romFound = false;
                    for (int i = 0; i < fbFile.Files.Length; i++)
                    {
                        if (radioButton_sha1.Checked)
                        {
                            if (fbFile.Files[i].SHA1.ToLower() == virtualRoms[j].SHA1.ToLower())
                            {
                                //this is it !!
                                console.Roms[j].Name = fbFile.Files[i].Name;
                                romsFound++; romFound = true;
                                foundRoms.Add(console.Roms[j].Name);
                                break;
                            }
                        }
                        if (radioButton_md5.Checked)
                        {
                            if (fbFile.Files[i].MD5.ToLower() == virtualRoms[j].MD5.ToLower())
                            {
                                //this is it !!
                                console.Roms[j].Name = fbFile.Files[i].Name;
                                romsFound++; romFound = true;
                                foundRoms.Add(console.Roms[j].Name);
                                break;
                            }
                        }
                        if (radioButton_crc.Checked)
                        {
                            if (fbFile.Files[i].CRC.ToLower() == virtualRoms[j].CRC.ToLower())
                            {
                                //this is it !!
                                console.Roms[j].Name = fbFile.Files[i].Name;
                                romsFound++; romFound = true;
                                foundRoms.Add(console.Roms[j].Name);
                                break;
                            }
                        }
                    }
                    if (!romFound)
                    {
                        missedRoms.Add(console.Roms[j].Name);
                        if (checkBox1.Checked)//delete rom
                        {
                            //real delete ?
                            if (checkBox2.Checked)
                            {
                                if (File.Exists(Utilities.GetFullPath(console.Roms[j].Path)))
                                {
                                    FileInfo fiinf = new FileInfo(Utilities.GetFullPath(console.Roms[j].Path));
                                    try
                                    {
                                        fiinf.IsReadOnly = false;
                                        File.Delete(Utilities.GetFullPath(console.Roms[j].Path));

                                    }
                                    catch { }
                                }
                                if (checkBox3.Checked)//delete snapshots, covers...
                                {
                                    foreach (string snap in console.Roms[j].Snapshots)
                                    {
                                        try
                                        {
                                            FileInfo fiinf = new FileInfo(Utilities.GetFullPath(snap));
                                            fiinf.IsReadOnly = false;
                                            File.Delete(Utilities.GetFullPath(snap));
                                        }
                                        catch { }
                                    }
                                    foreach (string snap in console.Roms[j].Covers)
                                    {
                                        try
                                        {
                                            FileInfo fiinf = new FileInfo(Utilities.GetFullPath(snap));
                                            fiinf.IsReadOnly = false;
                                            File.Delete(Utilities.GetFullPath(snap));
                                        }
                                        catch { }
                                    }
                                    foreach (string snap in console.Roms[j].SoundRecords)
                                    {
                                        try
                                        {
                                            FileInfo fiinf = new FileInfo(Utilities.GetFullPath(snap));
                                            fiinf.IsReadOnly = false;
                                            File.Delete(Utilities.GetFullPath(snap));
                                        }
                                        catch { }
                                    }
                                    try
                                    {
                                        FileInfo fiinf = new FileInfo(Utilities.GetFullPath(console.Roms[j].PDFPath));
                                        fiinf.IsReadOnly = false;
                                        File.Delete(Utilities.GetFullPath(console.Roms[j].PDFPath));
                                    }
                                    catch { }
                                    try
                                    {
                                        foreach (string snap in console.Roms[j].Videos)
                                        {
                                            try
                                            {
                                                FileInfo fiinf = new FileInfo(Utilities.GetFullPath(snap));
                                                fiinf.IsReadOnly = false;
                                                File.Delete(Utilities.GetFullPath(snap));
                                            }
                                            catch { }
                                        }
                                    }
                                    catch { }
                                    //info and history
                                    try
                                    {
                                        FileInfo fiinf = new FileInfo(Utilities.GetFullPath(console.InfoFolder) + "\\"
                                            + Path.GetFileNameWithoutExtension(console.Roms[j].Path) + ".txt");
                                        fiinf.IsReadOnly = false;
                                        File.Delete(Utilities.GetFullPath(console.InfoFolder) + "\\"
                                            + Path.GetFileNameWithoutExtension(console.Roms[j].Path) + ".txt");
                                    }
                                    catch { }
                                    try
                                    {
                                        FileInfo fiinf = new FileInfo(Utilities.GetFullPath(console.InfoFolder) + "\\"
                                            + Path.GetFileNameWithoutExtension(console.Roms[j].Path) + ".rtf");
                                        fiinf.IsReadOnly = false;
                                        File.Delete(Utilities.GetFullPath(console.InfoFolder) + "\\"
                                            + Path.GetFileNameWithoutExtension(console.Roms[j].Path) + ".rtf");
                                    }
                                    catch { }
                                }
                            }

                            //delete from database
                            console.Roms.RemoveAt(j);
                            virtualRoms.RemoveAt(j);
                            j--;

                        }
                    }
                    progressBar1.Value = (realJ * 100) / realS;
                    label1.Text = "Applying names that found (" + progressBar1.Value + " %), " + romsFound + " name applyed.";
                    Application.DoEvents();
                    realJ++;
                }
                Log.Add("[FOUND ROMS " + foundRoms.Count + " TOTAL]");
                foreach (string rom in foundRoms)
                    Log.Add(rom);
                Log.Add("");
                Log.Add("[MISSED ROMS " + missedRoms.Count + " TOTAL]");
                foreach (string rom in missedRoms)
                    Log.Add(rom);
            }
            //done
            this.DialogResult = System.Windows.Forms.DialogResult.OK;
            this.Close();

            if (MessageBox.Show("Done !!\n" + romsFound + " Rom(s) got name(s) from database !!\nSave Log ?", "Get Rom Names From Database",
                MessageBoxButtons.YesNo, MessageBoxIcon.Question) == System.Windows.Forms.DialogResult.Yes)
            {
                SaveFileDialog sav = new SaveFileDialog();
                sav.Filter = "Text File (*.txt)|*.txt";
                if (sav.ShowDialog(this) == System.Windows.Forms.DialogResult.OK)
                {
                    File.WriteAllLines(sav.FileName, Log.ToArray(), Encoding.Unicode);
                }
            }
        }

        void fbFile_Progress(object sender, ProgressArg e)
        {
            label1.Text = e.Status + "(" + e.PrecentageCompleted + " %)";
            progressBar1.Value = e.PrecentageCompleted;
            Application.DoEvents();
        }
        private void button3_Click(object sender, EventArgs e)
        {
            Close();
        }
        private void checkBox1_CheckedChanged(object sender, EventArgs e)
        {
            checkBox2.Enabled = checkBox3.Enabled = checkBox1.Checked;
        }
        private void checkBox2_CheckedChanged(object sender, EventArgs e)
        {
            label3.Visible = checkBox2.Checked | checkBox3.Checked;
        }
        private void checkBox3_CheckedChanged(object sender, EventArgs e)
        {
            label3.Visible = checkBox2.Checked | checkBox3.Checked;
        }
    }
}
