﻿/*  
     This file is part of Emulators Organizer
    A program that organize emulators and roms.
   
    Copyright (C) 2009 - 2012  Ali Hadid, programmed by Ala Hadid

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.IO;
using System.Windows.Forms;
using System.Diagnostics;
using AHD.Emulators_Organizer.Base;

namespace EmulatorsOrganizer.Frms
{
    public partial class Frm_RomProperties : Form
    {
        Rom _SelectedRom;
        int _SelectedRomIndex = 0;
        EmuConsole _ParentConsole;
        CommandLineGroupsEmulator SelectedGroupsEmulator;
        public Frm_RomProperties(Rom SelectedRom, EmuConsole ParentConsole)
        {
            _SelectedRom = SelectedRom;
            _ParentConsole = ParentConsole;
            InitializeComponent();
            //Add the roms into the list
            foreach (Rom ro in _ParentConsole.Roms)
            {
                listBox1.Items.Add(ro.Name);
            }
            listBox1.SelectedItem = _SelectedRom.Name;
            listBox1.Select();
            GetRomProperties();
            //refresh emulators
            foreach (Emulator emu in _ParentConsole.Emulators)
            {
                comboBox1.Items.Add(emu.Name);
            }
            if (comboBox1.Items.Count > 0)
                comboBox1.SelectedIndex = 0;
            else
            {
                commandlinesEditor1.CommandLinesGroups = null;
                commandlinesEditor1.Enabled = false;
            }
        }
        bool SaveRomProperties()
        {
            //Save the current rom
            if (textBox_name.Text.Length == 0)
            {
                MessageBox.Show("ENTER A NAME !!");
                return false;
            }
            if (radioButton1.Checked)
            {
                if (!File.Exists(textBox_path.Text))
                {
                    MessageBox.Show("Rom file isn't exist !!");
                    textBox_path.Select();
                    return false;
                }
            }
            else
            {
                if (textBox1_url.Text == "")
                {
                    MessageBox.Show("Please enter link of the rom file");
                    textBox1_url.Select();
                    return false;
                }
                if (textBox2_filename.Text == "")
                {
                    MessageBox.Show("Please enter download file name");
                    textBox2_filename.Select();
                    return false;
                }
                if (Path.GetExtension(textBox2_filename.Text) == null | Path.GetExtension(textBox2_filename.Text) == "")
                {
                    MessageBox.Show("Please enter extension of the download file name");
                    textBox2_filename.Select();
                    return false;
                }
                bool found = false;
                foreach (string ex in _ParentConsole.Extensions)
                {
                    if (ex.ToLower() == Path.GetExtension(textBox2_filename.Text).ToLower())
                    {
                        found = true;
                        break;
                    }
                }
                if (!found)
                {
                    MessageBox.Show("The extension of the download file name is not supported by the parent console '" + _ParentConsole.Name + "'");
                    textBox2_filename.Select();
                    return false;
                }
            }
            _SelectedRom.Name = textBox_name.Text;
            _SelectedRom.Path = textBox_path.Text;
            _SelectedRom.HasSpecialCommandLine = checkBox1.Checked;
            _SelectedRom.StateSaves.Clear();
            _SelectedRom.IsURL = !radioButton1.Checked;
            _SelectedRom.URL = textBox1_url.Text;
            _SelectedRom.DownloadFileName = textBox2_filename.Text;
            _SelectedRom.PDFPath = textBox1_maunal.Text;
            _SelectedRom.Year = (int)numericUpDown1.Value;
            listBox1.Items[_SelectedRomIndex] = _SelectedRom.Name;
            //state save
            _SelectedRom.StateSaves.Clear();
            foreach (string state in listBox2.Items)
            {
                _SelectedRom.StateSaves.Add(state);
            }
            //snaps
            _SelectedRom.Snapshots.Clear();
            foreach (string state in listBox3_snaps.Items)
            {
                _SelectedRom.Snapshots.Add(state);
            }
            //covers
            _SelectedRom.Covers.Clear();
            foreach (string state in listBox4_covers.Items)
            {
                _SelectedRom.Covers.Add(state);
            }
            return true;
        }
        void GetRomProperties()
        {
            pictureBox1.Image = pictureBox2.Image = null;
            pdFviewer1.PDFPath = _SelectedRom.PDFPath;
            textBox1_maunal.Text = _SelectedRom.PDFPath;
            _SelectedRomIndex = listBox1.SelectedIndex;
            textBox_name.Text = _SelectedRom.Name;
            textBox_path.Text = _SelectedRom.Path;
            radioButton1.Checked = !_SelectedRom.IsURL;
            radioButton2.Checked = _SelectedRom.IsURL;
            textBox1_url.Text = _SelectedRom.URL;
            textBox2_filename.Text = _SelectedRom.DownloadFileName;
            checkBox1.Checked = _SelectedRom.HasSpecialCommandLine;
            numericUpDown1.Value = _SelectedRom.Year;
            //Refresh state files
            if (_SelectedRom.StateSaves == null)
                _SelectedRom.StateSaves = new List<string>();
            listBox2.Items.Clear();
            foreach (string state in _SelectedRom.StateSaves)
            {
                listBox2.Items.Add(state);
            }
            if (listBox2.Items.Count > 0)
                listBox2.SelectedIndex = 0;
            //Refresh snapshots
            if (_SelectedRom.Snapshots == null)
                _SelectedRom.Snapshots = new List<string>();
            listBox3_snaps.Items.Clear();
            foreach (string state in _SelectedRom.Snapshots)
            {
                listBox3_snaps.Items.Add(state);
            }
            if (listBox3_snaps.Items.Count > 0)
                listBox3_snaps.SelectedIndex = 0;
            //Refresh covers
            if (_SelectedRom.Covers == null)
                _SelectedRom.Covers = new List<string>();
            listBox4_covers.Items.Clear();
            foreach (string state in _SelectedRom.Covers)
            {
                listBox4_covers.Items.Add(state);
            }
            if (listBox4_covers.Items.Count > 0)
                listBox4_covers.SelectedIndex = 0;

            commandlinesEditor1.CommandLinesGroups = null;
            comboBox1.Enabled = commandlinesEditor1.Enabled = checkBox1.Checked;
            comboBox1_SelectedIndexChanged(this, null);
        }
        private void listBox1_Click(object sender, EventArgs e)
        {
            SaveRomProperties();
            _SelectedRom = _ParentConsole.Roms[listBox1.SelectedIndex];
            GetRomProperties();
        }
        //next
        private void button1_Click(object sender, EventArgs e)
        {
            if (SaveRomProperties())
            {
                try
                {
                    listBox1.SelectedIndex++;
                    listBox1_Click(this, null);
                }
                catch { }
            }
        }
        //previous
        private void button2_Click(object sender, EventArgs e)
        {
            if (SaveRomProperties())
            {
                try
                {
                    listBox1.SelectedIndex--;
                    listBox1_Click(this, null);
                }
                catch { }
            }
        }
        //ok
        private void button3_Click(object sender, EventArgs e)
        {
            if (SaveRomProperties())
            {
                this.DialogResult = System.Windows.Forms.DialogResult.OK;
                Close();
            }
        }
        //cancel
        private void button4_Click(object sender, EventArgs e)
        {
            this.DialogResult = System.Windows.Forms.DialogResult.Cancel;
            Close();
        }

        private void comboBox1_SelectedIndexChanged(object sender, EventArgs e)
        {
            if (_SelectedRom == null)
                return;
            if (comboBox1.SelectedIndex < 0)
                return;
            if (_SelectedRom.CommandLineGroupsEmulator == null)
                _SelectedRom.CommandLineGroupsEmulator = new List<CommandLineGroupsEmulator>();
            //1 Search for the command lines group emulator that holds up 
            //commandlines for selected emulator in the compobox
            bool found = false;
            foreach (CommandLineGroupsEmulator CEM in _SelectedRom.CommandLineGroupsEmulator)
            {
                if (CEM.Emulator == _ParentConsole.Emulators[comboBox1.SelectedIndex])
                {
                    SelectedGroupsEmulator = CEM;
                    commandlinesEditor1.CommandLinesGroups = CEM.CommandLinesGroups;
                    found = true;
                    return;
                }
            }
            if (!found)
            {
                SelectedGroupsEmulator = new CommandLineGroupsEmulator();
                SelectedGroupsEmulator.Emulator = _ParentConsole.Emulators[comboBox1.SelectedIndex];
                _SelectedRom.CommandLineGroupsEmulator.Add(SelectedGroupsEmulator);

                commandlinesEditor1.CommandLinesGroups = SelectedGroupsEmulator.CommandLinesGroups;
            }
        }

        private void checkBox1_CheckedChanged(object sender, EventArgs e)
        {
            comboBox1.Enabled = commandlinesEditor1.Enabled = checkBox1.Checked;
            comboBox1_SelectedIndexChanged(this, null);
        }

        private void linkLabel1_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
        {
            OpenFileDialog op = new OpenFileDialog();
            op.Title = "Open state save file";
            op.Filter = "All files|*.*";
            if (op.ShowDialog(this) == System.Windows.Forms.DialogResult.OK)
            {
                foreach (string state in listBox2.Items)
                {
                    if (state == op.FileName)
                    {
                        return;
                    }
                }
                listBox2.Items.Add(op.FileName);
            }
        }

        private void linkLabel2_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
        {
            if (listBox2.SelectedIndex >= 0)
                listBox2.Items.RemoveAt(listBox2.SelectedIndex);
        }
        private void listBox1_KeyUp(object sender, KeyEventArgs e)
        {
            SaveRomProperties();
            _SelectedRom = _ParentConsole.Roms[listBox1.SelectedIndex];
            GetRomProperties();
        }

        private void radioButton1_CheckedChanged(object sender, EventArgs e)
        {
            linkLabel3.Enabled = textBox_path.Enabled = radioButton1.Checked;
            textBox1_url.Enabled = !radioButton1.Checked;
            textBox2_filename.Enabled = !radioButton1.Checked;
        }

        private void linkLabel3_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
        {
            OpenFileDialog fil = new OpenFileDialog();
            fil.Title = "Add roms";
            string filter = _ParentConsole.Name + " roms (";
            if (_ParentConsole.Extensions.Count == 1)
            { filter += "*" + _ParentConsole.Extensions[0]; }
            else
            {
                foreach (string ext in _ParentConsole.Extensions)
                {
                    filter += "*" + ext;
                    if (_ParentConsole.Extensions[_ParentConsole.Extensions.Count - 1] != ext)
                    { filter += ","; }
                }
            }
            filter += ")|";
            foreach (string ext in _ParentConsole.Extensions)
            {
                filter += "*" + ext + ";";
            }
            fil.Filter = filter;
            if (fil.ShowDialog(this) == DialogResult.OK)
            {
                textBox_path.Text = fil.FileName;
            }
        }

        private void textBox1_url_Validated(object sender, EventArgs e)
        {
            try
            {
                string[] splited = textBox1_url.Text.Split(new char[] { '/' });
                textBox2_filename.Text = splited[splited.Length - 1];
                textBox2_filename.Text = textBox2_filename.Text.Replace("%20", " ");
            }
            catch { }
        }

        private void listBox4_covers_SelectedIndexChanged(object sender, EventArgs e)
        {
            try
            {
                pictureBox2.Image = Image.FromFile(listBox4_covers.SelectedItem.ToString());
            }
            catch { pictureBox2.Image = null; }
        }

        private void listBox3_snaps_SelectedIndexChanged(object sender, EventArgs e)
        {
            try
            {
                pictureBox1.Image = Image.FromFile(listBox3_snaps.SelectedItem.ToString());
            }
            catch { pictureBox1.Image = null; }
        }

        private void linkLabel7_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
        {
            OpenFileDialog op = new OpenFileDialog();
            op.Multiselect = true;
            op.Title = "Open image file";
            op.Filter = "Supported image types (*.jpg;*.png;*.bmp;*.gif;*.jpeg;*.tiff;*.tga)|*.jpg;*.png;*.bmp;*.gif;*.jpeg;*.tiff;*.tga";
            if (op.ShowDialog(this) == System.Windows.Forms.DialogResult.OK)
            {
                for (int i = 0; i < op.FileNames.Length; i++)
                {
                    bool found = false;
                    foreach (string state in listBox4_covers.Items)
                    {
                        if (state == op.FileNames[i])
                        {
                            found = true;
                            break;
                        }
                    }
                    if (!found)
                        listBox4_covers.Items.Add(op.FileNames[i]);
                }
            }
        }

        private void linkLabel5_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
        {
            OpenFileDialog op = new OpenFileDialog();
            op.Title = "Open image file";
            op.Multiselect = true;
            op.Filter = "Supported image types (*.jpg;*.png;*.bmp;*.gif;*.jpeg;*.tiff;*.tga)|*.jpg;*.png;*.bmp;*.gif;*.jpeg;*.tiff;*.tga";
            if (op.ShowDialog(this) == System.Windows.Forms.DialogResult.OK)
            {
                for (int i = 0; i < op.FileNames.Length; i++)
                {
                    bool found = false;
                    foreach (string state in listBox3_snaps.Items)
                    {
                        if (state == op.FileNames[i])
                        {
                            found = true;
                            break;
                        }
                    }
                    if (!found)
                        listBox3_snaps.Items.Add(op.FileNames[i]);
                }
            }
        }

        private void linkLabel4_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
        {
            if (listBox3_snaps.SelectedIndex >= 0)
                listBox3_snaps.Items.RemoveAt(listBox3_snaps.SelectedIndex);
        }

        private void linkLabel6_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
        {
            if (listBox4_covers.SelectedIndex >= 0)
                listBox4_covers.Items.RemoveAt(listBox4_covers.SelectedIndex);
        }

        private void pdFviewer1_PDFchangeFileRequest(object sender, EventArgs e)
        {
            OpenFileDialog op = new OpenFileDialog();
            op.Title = "Open manual file";
            op.Filter = "(*.pdf)|*.pdf;*.PDF";
            if (op.ShowDialog(this) == System.Windows.Forms.DialogResult.OK)
            {
                textBox1_maunal.Text = op.FileName;
                pdFviewer1.PDFPath = op.FileName;
            }
        }

        private void pdFviewer1_PDFdeleteFileRequest(object sender, EventArgs e)
        {
            textBox1_maunal.Text = "";
            pdFviewer1.PDFPath = "";
        }

        private void pdFviewer1_PDFrealDeleteFileRequest(object sender, EventArgs e)
        {
            MessageBox.Show("Can't do this here.");
        }

        private void linkLabel8_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
        {
            try
            {
                Process.Start("explorer.exe", @"/select, " + textBox_path.Text);
            }
            catch { }
        }

        private void listBox2_MouseDoubleClick(object sender, MouseEventArgs e)
        {
            try
            {
                Process.Start("explorer.exe", @"/select, " + listBox2.SelectedItem.ToString());
            }
            catch { }
        }

        private void listBox3_snaps_MouseDoubleClick(object sender, MouseEventArgs e)
        {
            try
            {
                Process.Start("explorer.exe", @"/select, " + listBox3_snaps.SelectedItem.ToString());
            }
            catch { }
        }

        private void listBox4_covers_MouseDoubleClick(object sender, MouseEventArgs e)
        {
            try
            {
                Process.Start("explorer.exe", @"/select, " + listBox4_covers.SelectedItem.ToString());
            }
            catch { }
        }

        private void linkLabel9_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
        {
            try
            {
                Process.Start("explorer.exe", @"/select, " + textBox1_maunal.Text);
            }
            catch { }
        }
    }
}
