﻿/*  
     This file is part of Emulators Organizer
    A program that organize emulators and roms.
   
    Copyright (C) 2009 - 2012  Ali Hadid, programmed by Ala Hadid

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.IO;
using System.Threading;
using System.Diagnostics;
using AHD.Emulators_Organizer.Base;
using AHD.Utilities;

namespace EmulatorsOrganizer.Frms
{
    public partial class Frm_SendTo : Form
    {
        public Frm_SendTo(Rom[] RomItems, EmuConsole[] Consoles)
        {
            settings.Reload();
            _RomItems = RomItems;
            _consoles = Consoles;
            InitializeComponent();
            textBox1.Text = settings.SendToFolder;
            textBox_snaps.Text = settings.SendToSnapsFolder;
            textBox_covers.Text = settings.SendToCoversFolder;
            textBox_manuals.Text = settings.SendtoManualsFolder;
            textBox2_info.Text = settings.SendtoinfosFolder;
            textBox3_history.Text = settings.SendtohistoryFolder;
            textBox2_sound.Text = settings.SendtoSound;
            textBox2_video.Text = settings.SendtoVideo;
            comboBox_ArchiveFormat.SelectedIndex = 0;
            comboBox_CopressinLevel.SelectedItem = "Normal";
            labelInfo.Text = _RomItems.Length + " rom(s) ready to send";
        }
        bool _deleteRoms = false;
        string _ArchiveExtension = "";
        Thread m_thread;
        Rom[] _RomItems;
        EmuConsole[] _consoles;
        SevenZip.OutArchiveFormat _ArchiveFormat = SevenZip.OutArchiveFormat.SevenZip;
        SevenZip.CompressionLevel _CompressionLevel = SevenZip.CompressionLevel.Fast;
        public bool DeleteRoms
        { get { return _deleteRoms; } }
        private delegate void EnableDisable();
        private delegate void SetLabelDelegate(string text);
        private delegate void SetNumericValueDelegate(int value);
        Settings1 settings = new Settings1();
        void DisableButtons()
        {
            if (!this.InvokeRequired)
            {
                DisableButtonsAndGr();
            }
            else
            {
                this.Invoke(new EnableDisable(DisableButtonsAndGr));
            }
        }
        void EnableButtons()
        {
            if (!this.InvokeRequired)
            {
                EnableButtonsAndGr();
            }
            else
            {
                this.Invoke(new EnableDisable(EnableButtonsAndGr));
            }
        }
        void SetStatus(string text)
        {
            if (!this.InvokeRequired)
            {
                this.SetLabelStatus(text);
            }
            else
            {
                this.Invoke(new SetLabelDelegate(SetLabelStatus), text);
            }
        }
        void SetStatus1(string text)
        {
            if (!this.InvokeRequired)
            {
                this.SetLabelStatus1(text);
            }
            else
            {
                this.Invoke(new SetLabelDelegate(SetLabelStatus1), text);
            }
        }
        void SetMaximumBar(int value)
        {
            if (value != -1)
            {
                if (!this.InvokeRequired)
                {
                    this.SetProgressMaximum(value);
                }
                else
                {
                    this.Invoke(new SetNumericValueDelegate(SetProgressMaximum), value);
                }
            }
        }
        void SetProgress(int value)
        {
            if (!this.InvokeRequired)
            {
                progressBar1.Value = value;
            }
            else
            {
                this.Invoke(new SetNumericValueDelegate(SetProgressValue), value);
            }
        }
        void SetMaximumBar1(int value)
        {
            if (value != -1)
            {
                if (!this.InvokeRequired)
                {
                    this.SetProgressMaximum1(value);
                }
                else
                {
                    this.Invoke(new SetNumericValueDelegate(SetProgressMaximum1), value);
                }
            }
        }
        void SetProgress1(int value)
        {
            if (!this.InvokeRequired)
            {
                progressBar2.Value = value;
            }
            else
            {
                this.Invoke(new SetNumericValueDelegate(SetProgressValue1), value);
            }
        }
        private void EnableButtonsAndGr()
        {
            groupBox1.Enabled = true;
            groupBox4.Enabled = (checkBox_CopySnap.Checked);
            groupBox2.Enabled = true;
            button3.Enabled = true;
            button2.Text = "&Start";
        }
        private void DisableButtonsAndGr()
        {
            groupBox1.Enabled = false;
            groupBox4.Enabled = false;
            groupBox2.Enabled = false;
            button3.Enabled = false;
            button2.Text = "&Abort";
        }
        private void SetLabelStatus(string text)
        {
            statuslabel.Text = text;
        }
        private void SetLabelStatus1(string text)
        {
            StatusLabel_Compress.Text = text;
        }
        private void SetProgressValue(int value)
        {
            this.progressBar1.Value = value;
        }
        private void SetProgressMaximum(int maximum)
        {
            this.progressBar1.Maximum = maximum;
        }
        private void SetProgressValue1(int value)
        {
            this.progressBar2.Value = value;
        }
        private void SetProgressMaximum1(int maximum)
        {
            this.progressBar2.Maximum = maximum;
        }
        void PROGRESS()
        {
            SevenZip.SevenZipCompressor comper = new SevenZip.SevenZipCompressor();
            comper.ArchiveFormat = _ArchiveFormat;
            comper.CompressionLevel = _CompressionLevel;
            comper.Compressing += new EventHandler<SevenZip.ProgressEventArgs>(comper_Compressing);
            comper.FileCompressionStarted += new EventHandler<SevenZip.FileNameEventArgs>(comper_FileCompressionStarted);
            int MoveCopy_errors = 0;
            int CopySnap_errors = 0;
            int CopyCovers_errors = 0;
            int Extract_errors = 0;
            int CopyManualsErrors = 0;
            int CopyInfosErrors = 0;
            int CopyHistoryErrors = 0;
            int CopyVideoErrors = 0;
            int CopySoundErrors = 0;
            DisableButtons();
            #region Empty
            if (checkBox_Empty.Checked)
            {
                string[] files = Directory.GetFiles(textBox1.Text, "*", SearchOption.AllDirectories);
                SetMaximumBar(files.Length);
                for (int j = 0; j < files.Length; j++)
                {
                    SetProgress(j);
                    int Precento = (100 * j) / files.Length;
                    SetStatus("Emptying the destination folder " + Precento + "%");
                    SetProgress1(Precento);
                    try
                    {
                        FileInfo inf = new FileInfo(files[j]);
                        inf.IsReadOnly = false;
                        File.Delete(files[j]);
                    }
                    catch { }
                }
                string[] directories = Directory.GetDirectories(textBox1.Text, "*", SearchOption.AllDirectories);
                SetMaximumBar(directories.Length);
                for (int j = 0; j < directories.Length; j++)
                {
                    SetProgress(j);
                    int Precento = (100 * j) / directories.Length;
                    SetStatus("Emptying the destination folder " + Precento + "%");
                    SetProgress1(Precento);
                    try
                    {
                        Directory.Delete(directories[j]);
                    }
                    catch { }
                }
                //Empty the destination snapshots folder
                if (checkBox_CopySnap.Checked)
                {
                    files = Directory.GetFiles(textBox_snaps.Text, "*", SearchOption.AllDirectories);
                    directories = Directory.GetDirectories(textBox_snaps.Text, "*", SearchOption.AllDirectories);
                    SetMaximumBar(files.Length);
                    for (int j = 0; j < files.Length; j++)
                    {
                        SetProgress(j);
                        int Precento = (100 * j) / files.Length;
                        SetStatus("Emptying the destination snapshots folder " + Precento + "%");
                        SetProgress1(Precento);
                        try
                        {
                            FileInfo inf = new FileInfo(files[j]);
                            inf.IsReadOnly = false;
                            File.Delete(files[j]);
                        }
                        catch { }
                    }
                    SetMaximumBar(directories.Length);
                    for (int j = 0; j < directories.Length; j++)
                    {
                        SetProgress(j);
                        int Precento = (100 * j) / directories.Length;
                        SetStatus("Emptying the destination snapshots folder " + Precento + "%");
                        SetProgress1(Precento);
                        try
                        {
                            Directory.Delete(directories[j]);
                        }
                        catch { }
                    }
                }
                //Empty the destination covers folder
                if (checkBox_withcovers.Checked)
                {
                    files = Directory.GetFiles(textBox_covers.Text, "*", SearchOption.AllDirectories);
                    directories = Directory.GetDirectories(textBox_covers.Text, "*", SearchOption.AllDirectories);
                    SetMaximumBar(files.Length);
                    for (int j = 0; j < files.Length; j++)
                    {
                        SetProgress(j);
                        int Precento = (100 * j) / files.Length;
                        SetStatus("Emptying the destination covers folder " + Precento + "%");
                        SetProgress1(Precento);
                        try
                        {
                            FileInfo inf = new FileInfo(files[j]);
                            inf.IsReadOnly = false;
                            File.Delete(files[j]);
                        }
                        catch { }
                    }
                    SetMaximumBar(directories.Length);
                    for (int j = 0; j < directories.Length; j++)
                    {
                        SetProgress(j);
                        int Precento = (100 * j) / directories.Length;
                        SetStatus("Emptying the destination covers folder " + Precento + "%");
                        SetProgress1(Precento);
                        try
                        {
                            Directory.Delete(directories[j]);
                        }
                        catch { }
                    }
                }
                //Empty the destination manuals folder
                if (checkBox_withmanual.Checked)
                {
                    files = Directory.GetFiles(textBox_manuals.Text, "*", SearchOption.AllDirectories);
                    directories = Directory.GetDirectories(textBox_manuals.Text, "*", SearchOption.AllDirectories);
                    SetMaximumBar(files.Length);
                    for (int j = 0; j < files.Length; j++)
                    {
                        SetProgress(j);
                        int Precento = (100 * j) / files.Length;
                        SetStatus("Emptying the destination manuals folder " + Precento + "%");
                        SetProgress1(Precento);
                        try
                        {
                            FileInfo inf = new FileInfo(files[j]);
                            inf.IsReadOnly = false;
                            File.Delete(files[j]);
                        }
                        catch { }
                    }
                    SetMaximumBar(directories.Length);
                    for (int j = 0; j < directories.Length; j++)
                    {
                        SetProgress(j);
                        int Precento = (100 * j) / directories.Length;
                        SetStatus("Emptying the destination manuals folder " + Precento + "%");
                        SetProgress1(Precento);
                        try
                        {
                            Directory.Delete(directories[j]);
                        }
                        catch { }
                    }
                }
                //Empty the destination info folder
                if (checkBox1_withinfo.Checked)
                {
                    files = Directory.GetFiles(textBox2_info.Text, "*", SearchOption.AllDirectories);
                    directories = Directory.GetDirectories(textBox2_info.Text, "*", SearchOption.AllDirectories);
                    SetMaximumBar(files.Length);
                    for (int j = 0; j < files.Length; j++)
                    {
                        SetProgress(j);
                        int Precento = (100 * j) / files.Length;
                        SetStatus("Emptying the destination info files folder " + Precento + "%");
                        SetProgress1(Precento);
                        try
                        {
                            FileInfo inf = new FileInfo(files[j]);
                            inf.IsReadOnly = false;
                            File.Delete(files[j]);
                        }
                        catch { }
                    }
                    SetMaximumBar(directories.Length);
                    for (int j = 0; j < directories.Length; j++)
                    {
                        SetProgress(j);
                        int Precento = (100 * j) / directories.Length;
                        SetStatus("Emptying the destination info files folder " + Precento + "%");
                        SetProgress1(Precento);
                        try
                        {
                            Directory.Delete(directories[j]);
                        }
                        catch { }
                    }
                }
                //Empty the destination history folder
                if (checkBox2_withhistory.Checked)
                {
                    files = Directory.GetFiles(textBox3_history.Text, "*", SearchOption.AllDirectories);
                    directories = Directory.GetDirectories(textBox3_history.Text, "*", SearchOption.AllDirectories);
                    SetMaximumBar(files.Length);
                    for (int j = 0; j < files.Length; j++)
                    {
                        SetProgress(j);
                        int Precento = (100 * j) / files.Length;
                        SetStatus("Emptying the destination history files folder " + Precento + "%");
                        SetProgress1(Precento);
                        try
                        {
                            FileInfo inf = new FileInfo(files[j]);
                            inf.IsReadOnly = false;
                            File.Delete(files[j]);
                        }
                        catch { }
                    }
                    SetMaximumBar(directories.Length);
                    for (int j = 0; j < directories.Length; j++)
                    {
                        SetProgress(j);
                        int Precento = (100 * j) / directories.Length;
                        SetStatus("Emptying the destination history files folder " + Precento + "%");
                        SetProgress1(Precento);
                        try
                        {
                            Directory.Delete(directories[j]);
                        }
                        catch { }
                    }
                }
            }
            #endregion
            SetStatus("Preparing roms for the operation");
            SetMaximumBar(_RomItems.Length);
            int i = 0;
            foreach (Rom rom in _RomItems)
            {
                SetProgress(i);
                int Precent = (100 * i) / _RomItems.Length;
                if (checkBox_Move.Checked)//Move / Delete
                {
                    _deleteRoms = true;
                    if (!checkBox_Compress.Checked)
                    {
                        if (!checkBox_extract.Checked)
                        {
                            SetStatus("Moving roms " + Precent + "%");
                            SetStatus1((i + 1) + " of " + _RomItems.Length + " rom(s)");
                            SetProgress1(Precent);
                            try
                            {
                                File.Copy(Utilities.GetFullPath(rom.Path), textBox1.Text + "\\" + Path.GetFileName(rom.Path), true);
                                File.Delete(Utilities.GetFullPath(rom.Path));
                            }
                            catch { MoveCopy_errors++; }
                        }
                        else//Extract with delete
                        {
                            SetStatus("Extracting rom " + (i + 1) + " of " + _RomItems.Length + " (" + Precent + "%)");
                            if (File.Exists(Utilities.GetFullPath(rom.Path)))
                            {
                                try
                                {
                                    SevenZip.SevenZipExtractor extractor = new SevenZip.SevenZipExtractor(Utilities.GetFullPath(rom.Path));
                                    extractor.Extracting += new EventHandler<SevenZip.ProgressEventArgs>(extractor_Extracting);
                                    extractor.FileExtractionStarted += new EventHandler<SevenZip.FileInfoEventArgs>(extractor_FileExtractionStarted);
                                    string ExtractionDirectory = "";
                                    if (checkBox_SamePath.Checked)
                                        ExtractionDirectory = Path.GetDirectoryName(Utilities.GetFullPath(rom.Path));
                                    else
                                        ExtractionDirectory = textBox1.Text;

                                    if (checkBox_GreateFolder.Checked)
                                    {
                                        Directory.CreateDirectory(ExtractionDirectory + "\\" + Path.GetFileNameWithoutExtension(rom.Path));
                                        extractor.ExtractArchive(ExtractionDirectory + "\\" + Path.GetFileNameWithoutExtension(rom.Path));
                                    }
                                    else
                                    {
                                        extractor.ExtractArchive(ExtractionDirectory);
                                    }
                                }
                                catch { Extract_errors++; }

                                try
                                {
                                    File.Delete(Utilities.GetFullPath(rom.Path));
                                }
                                catch { MoveCopy_errors++; }
                            }
                            else
                                MoveCopy_errors++;
                        }
                    }
                    else//compress
                    {
                        SetStatus("Moving rom " + (i + 1) + " of " + _RomItems.Length + " (" + Precent + "%)");
                        if (File.Exists(Utilities.GetFullPath(rom.Path)))
                        {
                            if (!checkBox_Encrypt.Checked)
                                comper.CompressFiles(textBox1.Text + "\\" + Path.GetFileNameWithoutExtension(rom.Path) + _ArchiveExtension, new string[] { Utilities.GetFullPath(rom.Path) });
                            else
                                comper.CompressFilesEncrypted(textBox1.Text + "\\" + Path.GetFileNameWithoutExtension(rom.Path) + _ArchiveExtension, textBox_Password.Text, new string[] { Utilities.GetFullPath(rom.Path) });
                            try
                            {
                                File.Delete(Utilities.GetFullPath(rom.Path));
                            }
                            catch { MoveCopy_errors++; }

                        }
                    }
                    if (checkBox_CopySnap.Checked)
                    {
                        try
                        {
                            if (rom.Snapshots == null)
                                rom.Snapshots = new List<string>();
                            Directory.CreateDirectory(textBox_snaps.Text + "\\" + Path.GetFileNameWithoutExtension(rom.Path));
                            foreach (string snap in rom.Snapshots)
                            {
                                if (File.Exists(Utilities.GetFullPath(snap)))
                                {
                                    File.Copy(Utilities.GetFullPath(snap), textBox_snaps.Text + "\\" + Path.GetFileNameWithoutExtension(rom.Path) + "\\" + Path.GetFileName(snap), true);
                                    File.Delete(Utilities.GetFullPath(snap));
                                }
                            }
                        }
                        catch { CopySnap_errors++; }
                    }
                    if (checkBox_withcovers.Checked)
                    {
                        try
                        {
                            if (rom.Covers == null)
                                rom.Covers = new List<string>();
                            Directory.CreateDirectory(textBox_covers.Text + "\\" + Path.GetFileNameWithoutExtension(rom.Path));
                            foreach (string cover in rom.Covers)
                            {
                                if (File.Exists(Utilities.GetFullPath(cover)))
                                {
                                    File.Copy(Utilities.GetFullPath(cover), textBox_covers.Text + "\\" + Path.GetFileNameWithoutExtension(rom.Path) + "\\" + Path.GetFileName(cover), true);
                                    File.Delete(Utilities.GetFullPath(cover));
                                }
                            }
                        }
                        catch { CopyCovers_errors++; }
                    }
                    if (checkBox_withmanual.Checked)
                    {
                        try
                        {
                            if (File.Exists(Utilities.GetFullPath(rom.PDFPath)))
                            {
                                File.Copy(Utilities.GetFullPath(rom.PDFPath), textBox_manuals.Text + "\\" + Path.GetFileName(rom.PDFPath), true);
                                File.Delete(Utilities.GetFullPath(rom.PDFPath));
                            }

                        }
                        catch { CopyManualsErrors++; }
                    }
                    if (checkBox1_withVideo.Checked)
                    {
                        try
                        {
                            if (rom.Videos == null)
                                rom.Videos = new List<string>();
                            Directory.CreateDirectory(textBox2_video.Text + "\\" + Path.GetFileNameWithoutExtension(rom.Path));
                            foreach (string cover in rom.Videos)
                            {
                                if (File.Exists(Utilities.GetFullPath(cover)))
                                {
                                    File.Copy(Utilities.GetFullPath(cover), textBox2_video.Text + "\\" + Path.GetFileNameWithoutExtension(rom.Path) + "\\" + Path.GetFileName(cover), true);
                                    File.Delete(Utilities.GetFullPath(cover));
                                }
                            }
                        }
                        catch { CopyVideoErrors++; }
                    }
                    if (checkBox1_withinfo.Checked)
                    {
                        try
                        {
                            if (File.Exists(Utilities.GetFullPath(_consoles[i].InfoFolder + "\\" + Path.GetFileNameWithoutExtension(rom.Path) + ".txt")))
                            {
                                File.Copy(Utilities.GetFullPath(_consoles[i].InfoFolder + "\\" + Path.GetFileNameWithoutExtension(rom.Path) + ".txt"),
                                    textBox2_info.Text + "\\" + Path.GetFileNameWithoutExtension(rom.Path) + ".txt", true);
                                File.Delete(Utilities.GetFullPath(_consoles[i].InfoFolder + "\\" + Path.GetFileNameWithoutExtension(rom.Path) + ".txt"));
                            }
                            if (File.Exists(Utilities.GetFullPath(_consoles[i].InfoFolder + "\\" + Path.GetFileNameWithoutExtension(rom.Path) + ".rtf")))
                            {
                                File.Copy(Utilities.GetFullPath(_consoles[i].InfoFolder + "\\" + Path.GetFileNameWithoutExtension(rom.Path) + ".rtf"),
                                    textBox2_info.Text + "\\" + Path.GetFileNameWithoutExtension(rom.Path) + ".rtf", true);
                                File.Delete(Utilities.GetFullPath(_consoles[i].InfoFolder + "\\" + Path.GetFileNameWithoutExtension(rom.Path) + ".rtf"));
                            }
                        }
                        catch { CopyInfosErrors++; }
                    }
                    if (checkBox2_withhistory.Checked)
                    {
                        try
                        {
                            if (File.Exists(Utilities.GetFullPath(_consoles[i].HistoryFolder + "\\" + Path.GetFileNameWithoutExtension(rom.Path) + ".txt")))
                            {
                                File.Copy(Utilities.GetFullPath(_consoles[i].HistoryFolder + "\\" + Path.GetFileNameWithoutExtension(rom.Path) + ".txt"),
                                    textBox3_history.Text + "\\" + Path.GetFileNameWithoutExtension(rom.Path) + ".txt", true);
                                File.Delete(Utilities.GetFullPath(_consoles[i].HistoryFolder + "\\" + Path.GetFileNameWithoutExtension(rom.Path) + ".txt"));
                            }
                            if (File.Exists(Utilities.GetFullPath(_consoles[i].HistoryFolder + "\\" + Path.GetFileNameWithoutExtension(rom.Path) + ".rtf")))
                            {
                                File.Copy(Utilities.GetFullPath(_consoles[i].HistoryFolder + "\\" + Path.GetFileNameWithoutExtension(rom.Path) + ".rtf"),
                                    textBox3_history.Text + "\\" + Path.GetFileNameWithoutExtension(rom.Path) + ".rtf", true);
                                File.Delete(Utilities.GetFullPath(_consoles[i].HistoryFolder + "\\" + Path.GetFileNameWithoutExtension(rom.Path) + ".rtf"));
                            }
                        }
                        catch { CopyHistoryErrors++; }
                    }
                    if (checkBox2_withSounds.Checked)
                    {
                        try
                        {
                            if (rom.SoundRecords == null)
                                rom.SoundRecords = new List<string>();
                            Directory.CreateDirectory(textBox2_sound.Text + "\\" + Path.GetFileNameWithoutExtension(rom.Path));
                            foreach (string sound in rom.SoundRecords)
                            {
                                if (File.Exists(Utilities.GetFullPath(sound)))
                                {
                                    File.Copy(Utilities.GetFullPath(sound), textBox2_sound.Text + "\\" + Path.GetFileNameWithoutExtension(rom.Path) + "\\" + Path.GetFileName(sound), true);
                                    File.Delete(Utilities.GetFullPath(sound));
                                }
                            }
                        }
                        catch { CopySoundErrors++; }
                    }
                }
                else//COPY
                {
                    _deleteRoms = false;
                    if (!checkBox_Compress.Checked)
                    {
                        if (!checkBox_extract.Checked)
                        {
                            SetStatus("Copying roms " + Precent + "%");
                            SetStatus1((i + 1) + " of " + _RomItems.Length + " rom(s)");
                            SetProgress1(Precent);
                            try
                            {
                                File.Copy(Utilities.GetFullPath(rom.Path), textBox1.Text + "\\" + Path.GetFileName(rom.Path), true);
                            }
                            catch { MoveCopy_errors++; }
                        }
                        else//extract without delete
                        {
                            SetStatus("Extracting rom " + (i + 1) + " of " + _RomItems.Length + " (" + Precent + "%)");
                            if (File.Exists(Utilities.GetFullPath(rom.Path)))
                            {
                                try
                                {
                                    SevenZip.SevenZipExtractor extractor = new SevenZip.SevenZipExtractor(Utilities.GetFullPath(rom.Path));
                                    extractor.Extracting += new EventHandler<SevenZip.ProgressEventArgs>(extractor_Extracting);
                                    extractor.FileExtractionStarted += new EventHandler<SevenZip.FileInfoEventArgs>(extractor_FileExtractionStarted);
                                    string ExtractionDirectory = "";
                                    if (checkBox_SamePath.Checked)
                                        ExtractionDirectory = Path.GetDirectoryName(Utilities.GetFullPath(rom.Path));
                                    else
                                        ExtractionDirectory = textBox1.Text;

                                    if (checkBox_GreateFolder.Checked)
                                    {
                                        Directory.CreateDirectory(ExtractionDirectory + "\\" + Path.GetFileNameWithoutExtension(rom.Path));
                                        extractor.ExtractArchive(ExtractionDirectory + "\\" + Path.GetFileNameWithoutExtension(rom.Path));
                                    }
                                    else
                                    {
                                        extractor.ExtractArchive(ExtractionDirectory);
                                    }
                                }
                                catch { Extract_errors++; }
                            }
                            else
                            { Extract_errors++; }
                        }
                    }
                    else//compress
                    {
                        SetStatus("Copying rom " + (i + 1) + " of " + _RomItems.Length + " (" + Precent + "%)");
                        if (File.Exists(Utilities.GetFullPath(rom.Path)))
                        {
                            if (!checkBox_Encrypt.Checked)
                                comper.CompressFiles(textBox1.Text + "\\" + Path.GetFileNameWithoutExtension(rom.Path) + _ArchiveExtension, new string[] { Utilities.GetFullPath(rom.Path) });
                            else
                                comper.CompressFilesEncrypted(textBox1.Text + "\\" + Path.GetFileNameWithoutExtension(rom.Path) + _ArchiveExtension, textBox_Password.Text, new string[] { Utilities.GetFullPath(rom.Path) });
                        }
                    }
                    if (checkBox_CopySnap.Checked)
                    {
                        try
                        {
                            if (rom.Snapshots == null)
                                rom.Snapshots = new List<string>();
                            Directory.CreateDirectory(textBox_snaps.Text + "\\" + Path.GetFileNameWithoutExtension(rom.Path));
                            foreach (string snap in rom.Snapshots)
                            {

                                if (File.Exists(Utilities.GetFullPath(snap)))
                                {
                                    File.Copy(Utilities.GetFullPath(snap), textBox_snaps.Text + "\\" + Path.GetFileNameWithoutExtension(rom.Path) + "\\" + Path.GetFileName(snap), true);
                                }
                            }
                        }
                        catch { CopySnap_errors++; }
                    }
                    if (checkBox_withcovers.Checked)
                    {
                        try
                        {
                            Directory.CreateDirectory(textBox_covers.Text + "\\" + Path.GetFileNameWithoutExtension(rom.Path));
                            if (rom.Covers == null)
                                rom.Covers = new List<string>();
                            foreach (string cover in rom.Covers)
                            {
                                if (File.Exists(Utilities.GetFullPath(cover)))
                                {
                                    File.Copy(Utilities.GetFullPath(cover), textBox_covers.Text + "\\" + Path.GetFileNameWithoutExtension(rom.Path) + "\\" + Path.GetFileName(cover), true);
                                }
                            }
                        }
                        catch { CopyCovers_errors++; }
                    }
                    if (checkBox_withmanual.Checked)
                    {
                        try
                        {
                            if (File.Exists(Utilities.GetFullPath(rom.PDFPath)))
                            {
                                File.Copy(Utilities.GetFullPath(rom.PDFPath), textBox_manuals.Text + "\\" + Path.GetFileName(rom.PDFPath), true);
                            }
                        }
                        catch { CopyManualsErrors++; }
                    }
                    if (checkBox1_withinfo.Checked)
                    {
                        try
                        {
                            if (File.Exists(Utilities.GetFullPath(_consoles[i].InfoFolder + "\\" + Path.GetFileNameWithoutExtension(rom.Path) + ".txt")))
                            {
                                File.Copy(Utilities.GetFullPath(_consoles[i].InfoFolder + "\\" + Path.GetFileNameWithoutExtension(rom.Path) + ".txt"),
                                    textBox2_info.Text + "\\" + Path.GetFileNameWithoutExtension(rom.Path) + ".txt", true);
                            }
                            if (File.Exists(Utilities.GetFullPath(_consoles[i].InfoFolder + "\\" + Path.GetFileNameWithoutExtension(rom.Path) + ".rtf")))
                            {
                                File.Copy(Utilities.GetFullPath(_consoles[i].InfoFolder + "\\" + Path.GetFileNameWithoutExtension(rom.Path) + ".rtf"),
                                    textBox2_info.Text + "\\" + Path.GetFileNameWithoutExtension(rom.Path) + ".rtf", true);
                            }
                        }
                        catch { CopyInfosErrors++; }
                    }
                    if (checkBox2_withhistory.Checked)
                    {
                        try
                        {
                            if (File.Exists(Utilities.GetFullPath(_consoles[i].HistoryFolder + "\\" + Path.GetFileNameWithoutExtension(rom.Path) + ".txt")))
                            {
                                File.Copy(Utilities.GetFullPath(_consoles[i].HistoryFolder + "\\" + Path.GetFileNameWithoutExtension(rom.Path) + ".txt"),
                                    textBox3_history.Text + "\\" + Path.GetFileNameWithoutExtension(rom.Path) + ".txt", true);
                            }
                            if (File.Exists(Utilities.GetFullPath(_consoles[i].HistoryFolder + "\\" + Path.GetFileNameWithoutExtension(rom.Path) + ".rtf")))
                            {
                                File.Copy(Utilities.GetFullPath(_consoles[i].HistoryFolder + "\\" + Path.GetFileNameWithoutExtension(rom.Path) + ".rtf"),
                                    textBox3_history.Text + "\\" + Path.GetFileNameWithoutExtension(rom.Path) + ".rtf", true);
                            }
                        }
                        catch { CopyHistoryErrors++; }
                    }
                    if (checkBox1_withVideo.Checked)
                    {
                        try
                        {
                            Directory.CreateDirectory(textBox2_video.Text + "\\" + Path.GetFileNameWithoutExtension(rom.Path));
                            if (rom.Videos == null)
                                rom.Videos = new List<string>();
                            foreach (string cover in rom.Videos)
                            {
                                if (File.Exists(Utilities.GetFullPath(cover)))
                                {
                                    File.Copy(Utilities.GetFullPath(cover), textBox2_video.Text + "\\" + 
                                        Path.GetFileNameWithoutExtension(rom.Path) + "\\" + Path.GetFileName(cover), true);
                                }
                            }
                        }
                        catch { CopyVideoErrors++; }
                    }
                    if (checkBox2_withSounds.Checked)
                    {
                        try
                        {
                            if (rom.SoundRecords == null)
                                rom.SoundRecords = new List<string>();
                            Directory.CreateDirectory(textBox2_sound.Text + "\\" + Path.GetFileNameWithoutExtension(rom.Path));
                            foreach (string sound in rom.SoundRecords)
                            {
                                if (File.Exists(Utilities.GetFullPath(sound)))
                                {
                                    File.Copy(Utilities.GetFullPath(sound), textBox2_sound.Text + "\\" + Path.GetFileNameWithoutExtension(rom.Path) + "\\" + Path.GetFileName(sound), true);
                                }
                            }
                        }
                        catch { CopySoundErrors++; }
                    }
                }
                i++;
            }
            if (checkBox_Move.Checked)
            {
                if (!checkBox_extract.Checked)
                {
                    string statee = "Done";
                    if (MoveCopy_errors > 0)
                        statee += ", Faild to move " + MoveCopy_errors + " rom(s)";
                    if (CopySnap_errors > 0)
                        statee += ", faild to move " + CopySnap_errors + " snapshot file(s)";
                    if (CopyCovers_errors > 0)
                        statee += ", faild to move " + CopyCovers_errors + " cover file(s)";
                    if (CopyManualsErrors > 0)
                        statee += ", faild to move " + CopyManualsErrors + " manual (pdf) file(s)";
                    if (CopyInfosErrors > 0)
                        statee += ", faild to move " + CopyInfosErrors + " info text file(s)";
                    if (CopyHistoryErrors > 0)
                        statee += ", faild to move " + CopyHistoryErrors + " history text file(s)";
                    if (CopySoundErrors > 0)
                        statee += ", faild to move " + CopySoundErrors + " sound file(s)";
                    if (CopyVideoErrors > 0)
                        statee += ", faild to move " + CopyVideoErrors + " video file(s)";
                    SetStatus(statee);
                }
                else
                {
                    string statee = "Done";
                    if (MoveCopy_errors > 0)
                        statee += ", Faild to delete " + MoveCopy_errors + " rom(s)";
                    if (Extract_errors > 0)
                        statee += ", faild to extract " + Extract_errors + " file(s)";
                    if (CopySnap_errors > 0)
                        statee += ", faild to move " + CopySnap_errors + " snapshot file(s)";
                    if (CopyCovers_errors > 0)
                        statee += ", faild to move " + CopyCovers_errors + " cover file(s)";
                    if (CopyManualsErrors > 0)
                        statee += ", faild to move " + CopyManualsErrors + " manual (pdf) file(s)";
                    if (CopyInfosErrors > 0)
                        statee += ", faild to move " + CopyInfosErrors + " info text file(s)";
                    if (CopyHistoryErrors > 0)
                        statee += ", faild to move " + CopyHistoryErrors + " history text file(s)";
                    if (CopySoundErrors > 0)
                        statee += ", faild to move " + CopySoundErrors + " sound file(s)";
                    if (CopyVideoErrors > 0)
                        statee += ", faild to move " + CopyVideoErrors + " video file(s)";
                    SetStatus(statee);
                }
            }
            else
            {
                if (!checkBox_extract.Checked)
                {
                    string statee = "Done";
                    if (MoveCopy_errors > 0)
                        statee += ", Faild to copy " + MoveCopy_errors + " rom(s)";
                    if (CopySnap_errors > 0)
                        statee += ", faild to copy " + CopySnap_errors + " snapshot file(s)";
                    if (CopyCovers_errors > 0)
                        statee += ", faild to copy " + CopyCovers_errors + " cover file(s)";
                    if (CopyManualsErrors > 0)
                        statee += ", faild to copy " + CopyManualsErrors + " manual (pdf) file(s)";
                    if (CopyInfosErrors > 0)
                        statee += ", faild to copy " + CopyInfosErrors + " info text file(s)";
                    if (CopyHistoryErrors > 0)
                        statee += ", faild to copy " + CopyHistoryErrors + " history text file(s)";
                    if (CopySoundErrors > 0)
                        statee += ", faild to copy " + CopySoundErrors + " sound file(s)";
                    if (CopyVideoErrors > 0)
                        statee += ", faild to copy " + CopyVideoErrors + " video file(s)";
                    SetStatus(statee);
                }
                else
                {
                    string statee = "Done";
                    if (Extract_errors > 0)
                        statee += ", Faild to extract " + Extract_errors + " file(s)";
                    if (CopySnap_errors > 0)
                        statee += ", faild to copy " + CopySnap_errors + " snapshot file(s)";
                    if (CopyCovers_errors > 0)
                        statee += ", faild to copy " + CopyCovers_errors + " cover file(s)";
                    if (CopyManualsErrors > 0)
                        statee += ", faild to copy " + CopyManualsErrors + " manual (pdf) file(s)";
                    if (CopyInfosErrors > 0)
                        statee += ", faild to copy " + CopyInfosErrors + " info text file(s)";
                    if (CopyHistoryErrors > 0)
                        statee += ", faild to copy " + CopyHistoryErrors + " history text file(s)";
                    if (CopySoundErrors > 0)
                        statee += ", faild to copy " + CopySoundErrors + " sound file(s)";
                    if (CopyVideoErrors > 0)
                        statee += ", faild to copy " + CopyVideoErrors + " video file(s)";
                    SetStatus(statee);
                }
            }
            SetMaximumBar(100);
            SetProgress(100);
            SetMaximumBar1(100);
            SetProgress1(100);
            SetStatus1("Finished");
            EnableButtons();
            if (checkBox_Browse.Checked)
            {
                try { Process.Start(textBox1.Text); }
                catch { }
            }
        }

        void extractor_FileExtractionStarted(object sender, SevenZip.FileInfoEventArgs e)
        {
            SetProgress1(0);
        }
        void extractor_Extracting(object sender, SevenZip.ProgressEventArgs e)
        {
            SetProgress1(e.PercentDone);
            SetStatus1("Extracting " + e.PercentDone + "%");
        }

        void comper_FileCompressionStarted(object sender, SevenZip.FileNameEventArgs e)
        {
            SetProgress1(0);
        }
        void comper_Compressing(object sender, SevenZip.ProgressEventArgs e)
        {
            SetProgress1(e.PercentDone);
            SetStatus1("Compressing " + e.PercentDone + "%");
        }

        private void button1_Click(object sender, EventArgs e)
        {
            FolderBrowserDialog fol = new FolderBrowserDialog();
            fol.SelectedPath = textBox1.Text;
            fol.ShowNewFolderButton = true;
            fol.Description = "Select folder";
            if (fol.ShowDialog(this) == System.Windows.Forms.DialogResult.OK)
            {
                textBox1.Text = fol.SelectedPath;
                settings.SendToFolder = fol.SelectedPath; settings.Save();
            }
        }
        private void textBox1_TextChanged(object sender, EventArgs e)
        {
            groupBox2.Enabled = (textBox1.Text.Length > 0);
        }

        private void button5_Click(object sender, EventArgs e)
        {
            FolderBrowserDialog fol = new FolderBrowserDialog();
            fol.SelectedPath = textBox_snaps.Text;
            fol.ShowNewFolderButton = true;
            fol.Description = "Select folder";
            if (fol.ShowDialog(this) == System.Windows.Forms.DialogResult.OK)
            {
                textBox_snaps.Text = fol.SelectedPath;
                settings.SendToSnapsFolder = textBox_snaps.Text; settings.Save();
            }
        }

        private void checkBox_CopySnap_CheckedChanged(object sender, EventArgs e)
        {
            groupBox4.Enabled = checkBox_CopySnap.Checked;
        }
        //Close
        private void button3_Click(object sender, EventArgs e)
        {
            Close();
        }
        //START, ABORT
        private void button2_Click(object sender, EventArgs e)
        {
            if (!Directory.Exists(textBox1.Text))
            {
                MessageBox.Show("Destination folder isn't exist !!");
                return;
            }
            if (checkBox_CopySnap.Checked)
            {
                if (!Directory.Exists(textBox_snaps.Text))
                {
                    MessageBox.Show("Destination snapshots folder isn't exist !!");
                    return;
                }
                if (checkBox_Empty.Checked)
                {
                    //snap folder inside the folder
                    if (textBox1.Text.Length <= textBox_snaps.Text.Length
                        & Path.GetDirectoryName(textBox1.Text) != Path.GetDirectoryName(textBox_snaps.Text))
                    {
                        if (textBox_snaps.Text.Substring(0, textBox1.Text.Length) == textBox1.Text)
                        {
                            MessageBox.Show("Destination snapshots folder is inside the detination one ??!!\nUncheck the 'Empty' option if you want them like this.");
                            return;
                        }
                    }
                    //Folder inside the snap folder
                    if (textBox1.Text.Length >= textBox_snaps.Text.Length
                        & Path.GetDirectoryName(textBox1.Text) != Path.GetDirectoryName(textBox_snaps.Text))
                    {
                        if (textBox1.Text.Substring(0, textBox_snaps.Text.Length) == textBox_snaps.Text)
                        {
                            MessageBox.Show("Destination folder is inside the snapshots one ??!!\nUncheck the 'Empty' option if you want them like this.");
                            return;
                        }
                    }
                }
            }
            if (checkBox_withcovers.Checked)
            {
                if (!Directory.Exists(textBox_covers.Text))
                {
                    MessageBox.Show("Destination covers folder isn't exist !!");
                    return;
                }
                if (checkBox_Empty.Checked)
                {
                    //covers folder inside the folder
                    if (textBox1.Text.Length <= textBox_covers.Text.Length
                        & Path.GetDirectoryName(textBox1.Text) != Path.GetDirectoryName(textBox_covers.Text))
                    {
                        if (textBox_snaps.Text.Substring(0, textBox1.Text.Length) == textBox1.Text)
                        {
                            MessageBox.Show("Destination covers folder is inside the detination one ??!!\nUncheck the 'Empty' option if you want them like this.");
                            return;
                        }
                    }
                    //Folder inside the covers folder
                    if (textBox1.Text.Length >= textBox_covers.Text.Length
                        & Path.GetDirectoryName(textBox1.Text) != Path.GetDirectoryName(textBox_covers.Text))
                    {
                        if (textBox1.Text.Substring(0, textBox_covers.Text.Length) == textBox_covers.Text)
                        {
                            MessageBox.Show("Destination folder is inside the covers one ??!!\nUncheck the 'Empty' option if you want them like this.");
                            return;
                        }
                    }
                }
            }
            if (checkBox_withmanual.Checked)
            {
                if (!Directory.Exists(textBox_manuals.Text))
                {
                    MessageBox.Show("Destination manuals folder isn't exist !!");
                    return;
                }
                if (checkBox_Empty.Checked)
                {
                    //covers folder inside the folder
                    if (textBox1.Text.Length <= textBox_manuals.Text.Length
                        & Path.GetDirectoryName(textBox1.Text) != Path.GetDirectoryName(textBox_manuals.Text))
                    {
                        if (textBox_manuals.Text.Substring(0, textBox1.Text.Length) == textBox1.Text)
                        {
                            MessageBox.Show("Destination manuals folder is inside the detination one ??!!\nUncheck the 'Empty' option if you want them like this.");
                            return;
                        }
                    }
                    //Folder inside the covers folder
                    if (textBox1.Text.Length >= textBox_manuals.Text.Length
                        & Path.GetDirectoryName(textBox1.Text) != Path.GetDirectoryName(textBox_manuals.Text))
                    {
                        if (textBox1.Text.Substring(0, textBox_manuals.Text.Length) == textBox_manuals.Text)
                        {
                            MessageBox.Show("Destination folder is inside the manuals one ??!!\nUncheck the 'Empty' option if you want them like this.");
                            return;
                        }
                    }
                }
            }
            if (checkBox_Encrypt.Checked & textBox_Password.Text.Length < 0)
            {
                MessageBox.Show("Please enter a password for archive encryption !!");
                textBox_Password.Select();
                return;
            }
            _ArchiveExtension = "." + comboBox_ArchiveFormat.SelectedItem.ToString().ToLower();
            if (m_thread == null)
            {
                m_thread = new Thread(new ThreadStart(PROGRESS));
                m_thread.Start();
            }
            else if (!m_thread.IsAlive)
            {
                m_thread = new Thread(new ThreadStart(PROGRESS));
                m_thread.Start();
            }
            else
            {
                if (MessageBox.Show("Are you sure ?", "", MessageBoxButtons.YesNo, MessageBoxIcon.Question) == System.Windows.Forms.DialogResult.Yes)
                {
                    m_thread.Abort();
                    SetProgress(0);
                    SetProgress1(0);
                    SetStatus("Aborted by user");
                    SetStatus1("Aborted by user");
                    EnableButtons();
                }
            }
        }

        private void comboBox_ArchiveFormat_SelectedIndexChanged(object sender, EventArgs e)
        {
            switch (comboBox_ArchiveFormat.SelectedItem.ToString())
            {
                case "7z": _ArchiveFormat = SevenZip.OutArchiveFormat.SevenZip; break;
                case "Zip": _ArchiveFormat = SevenZip.OutArchiveFormat.Zip; break;
                case "BZip2": _ArchiveFormat = SevenZip.OutArchiveFormat.BZip2; break;
                case "GZip": _ArchiveFormat = SevenZip.OutArchiveFormat.GZip; break;
                case "Tar": _ArchiveFormat = SevenZip.OutArchiveFormat.Tar; break;
                case "XZ": _ArchiveFormat = SevenZip.OutArchiveFormat.XZ; break;
            }
        }

        private void comboBox_CopressinLevel_SelectedIndexChanged(object sender, EventArgs e)
        {
            switch (comboBox_CopressinLevel.SelectedItem.ToString())
            {
                case "Fast": _CompressionLevel = SevenZip.CompressionLevel.Fast; break;
                case "High": _CompressionLevel = SevenZip.CompressionLevel.High; break;
                case "Low": _CompressionLevel = SevenZip.CompressionLevel.Low; break;
                case "None": _CompressionLevel = SevenZip.CompressionLevel.None; break;
                case "Normal": _CompressionLevel = SevenZip.CompressionLevel.Normal; break;
                case "Ultra": _CompressionLevel = SevenZip.CompressionLevel.Ultra; break;
            }
        }

        private void checkBox_Compress_CheckedChanged(object sender, EventArgs e)
        {
            groupBox5.Enabled = checkBox_Compress.Checked;
            if (checkBox_Compress.Checked)
                checkBox_extract.Checked = false;
        }

        private void Frm_SendTo_FormClosing(object sender, FormClosingEventArgs e)
        {
            if (m_thread != null)
            {
                if (m_thread.IsAlive)
                {
                    if (MessageBox.Show("Are you sure ?", "", MessageBoxButtons.YesNo, MessageBoxIcon.Question) == System.Windows.Forms.DialogResult.Yes)
                    {
                        m_thread.Abort();
                        SetProgress(0);
                        SetProgress1(0);
                        SetStatus("Aborted by user");
                        SetStatus1("Aborted by user");
                        EnableButtons();
                    }
                    else
                    {
                        e.Cancel = true;
                    }
                }
            }
        }

        private void checkBox_Encrypt_CheckedChanged(object sender, EventArgs e)
        {
            textBox_Password.Enabled = checkBox_Encrypt.Checked;
        }

        private void checkBox1_CheckedChanged(object sender, EventArgs e)
        {
            if (checkBox_Empty.Checked)
            {
                MessageBox.Show("BE CAREFULL, this is real !!");
            }
        }

        private void checkBox_Move_CheckedChanged(object sender, EventArgs e)
        {
            if (checkBox_Move.Checked)
            {
                MessageBox.Show("BE CAREFULL, this is a real MOVE !!");
            }
        }

        private void button4_Click(object sender, EventArgs e)
        {
            Help.ShowHelp(this, ".\\Help.chm", HelpNavigator.KeywordIndex, "Send to");
        }

        private void checkBox2_CheckedChanged(object sender, EventArgs e)
        {
            if (checkBox_withcovers.Checked)
                checkBox_extract.Checked = false;
            groupBox7.Enabled = checkBox_withcovers.Checked;
        }

        private void checkBox1_CheckedChanged_1(object sender, EventArgs e)
        {
            if (checkBox_extract.Checked)
                checkBox_Compress.Checked = false;
            checkBox_Move.Text = checkBox_extract.Checked ? "Delete" : "Move";
            groupBox8.Enabled = checkBox_extract.Checked;
        }

        private void button6_Click(object sender, EventArgs e)
        {
            FolderBrowserDialog fol = new FolderBrowserDialog();
            fol.SelectedPath = textBox_snaps.Text;
            fol.ShowNewFolderButton = true;
            fol.Description = "Select folder";
            if (fol.ShowDialog(this) == System.Windows.Forms.DialogResult.OK)
            {
                textBox_covers.Text = fol.SelectedPath;
                settings.SendToCoversFolder = textBox_covers.Text; settings.Save();
            }
        }

        private void checkBox_withmanual_CheckedChanged(object sender, EventArgs e)
        {
            groupBox9.Enabled = checkBox_withmanual.Checked;
        }

        private void button7_Click(object sender, EventArgs e)
        {
            FolderBrowserDialog fol = new FolderBrowserDialog();
            fol.SelectedPath = textBox_snaps.Text;
            fol.ShowNewFolderButton = true;
            fol.Description = "Select folder";
            if (fol.ShowDialog(this) == System.Windows.Forms.DialogResult.OK)
            {
                textBox_manuals.Text = fol.SelectedPath;
                settings.SendtoManualsFolder = textBox_manuals.Text; settings.Save();
            }
        }

        private void button8_Click(object sender, EventArgs e)
        {
            FolderBrowserDialog fol = new FolderBrowserDialog();
            fol.SelectedPath = textBox2_info.Text;
            fol.ShowNewFolderButton = true;
            fol.Description = "Select folder";
            if (fol.ShowDialog(this) == System.Windows.Forms.DialogResult.OK)
            {
                textBox2_info.Text = fol.SelectedPath;
                settings.SendtoinfosFolder = textBox2_info.Text; settings.Save();
            }
        }

        private void button9_Click(object sender, EventArgs e)
        {
            FolderBrowserDialog fol = new FolderBrowserDialog();
            fol.SelectedPath = textBox3_history.Text;
            fol.ShowNewFolderButton = true;
            fol.Description = "Select folder";
            if (fol.ShowDialog(this) == System.Windows.Forms.DialogResult.OK)
            {
                textBox3_history.Text = fol.SelectedPath;
                settings.SendtohistoryFolder = textBox3_history.Text; settings.Save();
            }
        }

        private void checkBox1_withinfo_CheckedChanged(object sender, EventArgs e)
        {
            groupBox10.Enabled = checkBox1_withinfo.Checked;
        }

        private void checkBox2_withhistory_CheckedChanged(object sender, EventArgs e)
        {
            groupBox11.Enabled = checkBox2_withhistory.Checked;
        }

        private void button10_Click(object sender, EventArgs e)
        {
            FolderBrowserDialog fol = new FolderBrowserDialog();
            fol.SelectedPath = textBox2_video.Text;
            fol.ShowNewFolderButton = true;
            fol.Description = "Select folder";
            if (fol.ShowDialog(this) == System.Windows.Forms.DialogResult.OK)
            {
                textBox2_video.Text = fol.SelectedPath;
                settings.SendtoVideo = textBox2_video.Text; settings.Save();
            }
        }

        private void button11_Click(object sender, EventArgs e)
        {
            FolderBrowserDialog fol = new FolderBrowserDialog();
            fol.SelectedPath = textBox2_sound.Text;
            fol.ShowNewFolderButton = true;
            fol.Description = "Select folder";
            if (fol.ShowDialog(this) == System.Windows.Forms.DialogResult.OK)
            {
                textBox2_sound.Text = fol.SelectedPath;
                settings.SendtoSound = textBox2_sound.Text; settings.Save();
            }
        }
    }
}
