﻿/*  
     This file is part of Emulators Organizer
    A program that organize emulators and roms.
   
    Copyright (C) 2009 - 2012  Ali Hadid, programmed by Ala Hadid

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.IO;
using System.Windows.Forms;
using AHD.Emulators_Organizer.Base;

namespace EmulatorsOrganizer.Frms
{
    public partial class Frm_consoleProperties : Form
    {
        Project _pro;
        EmuConsole _console;
        public Frm_consoleProperties(EmuConsole console, Project pro)
        {
            _pro = pro;
            _console = console;
            InitializeComponent();
            textBox1.Text = console.Name;

            if (console.Icon != null)
                label_icon.Image = console.Icon;
            else
                label_icon.Image = Properties.Resources.cpu;

            comboBox1.Items.Clear();
            foreach (string ex in _console.Extensions)
            {
                comboBox1.Items.Add(ex);
            }
            if (comboBox1.Items.Count > 0)
                comboBox1.SelectedIndex = 0;

            textBox2.Text = _console.InfoFolder;
            textBox3.Text = _console.HistoryFolder;
            textBox4_downloadsFolder.Text = _console.DownloadsFolder;
            checkBox1.Checked = _console.CopyRomToDownloadsFolder;
        }
        //ok
        private void button1_Click(object sender, EventArgs e)
        {
            //check name
            if (textBox1.Text.Length == 0)
            {
                MessageBox.Show("Please enter name !!"); return;
            }
            foreach (EmuConsole con in _pro.Consoles)
            {
                if (textBox1.Text.ToLower() == con.Name.ToLower() & con != _console)
                {
                    MessageBox.Show("Name already taken !!"); return;
                }
            }
            _console.Name = textBox1.Text;
            _console.Icon = label_icon.Image;
            _console.Extensions.Clear();
            foreach (string ex in comboBox1.Items)
            {
                _console.Extensions.Add(ex);
            }
            _console.InfoFolder = textBox2.Text;
            _console.HistoryFolder = textBox3.Text;
            _console.DownloadsFolder = textBox4_downloadsFolder.Text;
            _console.CopyRomToDownloadsFolder = checkBox1.Checked;
            DialogResult = System.Windows.Forms.DialogResult.OK;
            Close();
        }

        private void button2_Click(object sender, EventArgs e)
        {
            Close();
        }

        private void comboBox1_SelectedIndexChanged(object sender, EventArgs e)
        {
            linkLabel2.Enabled = comboBox1.SelectedIndex >= 0;
        }

        private void linkLabel1_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
        {
            Frm_EnterName name = new Frm_EnterName("Enter extension", "");
            if (name.ShowDialog(this) == System.Windows.Forms.DialogResult.OK)
            {
                int i = 0;
                foreach (string ex in comboBox1.Items)
                {
                    if (ex.ToLower() == "." + name.NameEntered.ToLower())
                    {
                        comboBox1.SelectedIndex = i;
                        return;
                    }
                    i++;
                }
                comboBox1.Items.Add("." + name.NameEntered.ToLower());
                comboBox1.SelectedIndex = comboBox1.Items.Count - 1;
            }
        }

        private void linkLabel2_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
        {
            if (comboBox1.Items.Count > 0)
            {
                comboBox1.Items.RemoveAt(comboBox1.SelectedIndex);
            }
            if (comboBox1.Items.Count > 0)
                comboBox1.SelectedIndex = 0;
        }

        private void label_icon_Click(object sender, EventArgs e)
        {
            OpenFileDialog Op = new OpenFileDialog();
            Op.Title = "Browse for an icon";
            Op.Filter = "Icon (*.jpg;*.png;*.bmp;*.gif;*.jpeg;*.tiff;*.tga;*.ico;*.exe)|*.jpg;*.png;*.bmp;*.gif;*.jpeg;*.tiff;*.tga;*.ico;*.exe";
            Op.Multiselect = false;
            if (Op.ShowDialog(this) == DialogResult.OK)
            {
                if (Path.GetExtension(Op.FileName).ToLower() == ".exe" | Path.GetExtension(Op.FileName).ToLower() == ".ico")
                { label_icon.Image = Icon.ExtractAssociatedIcon(Op.FileName).ToBitmap(); }
                else { label_icon.Image = Image.FromFile(Op.FileName); }
            }
        }

        private void linkLabel3_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
        {
            FolderBrowserDialog fo = new FolderBrowserDialog();
            fo.Description = "Info folder";
            if (fo.ShowDialog(this) == System.Windows.Forms.DialogResult.OK)
                textBox2.Text = fo.SelectedPath;
        }

        private void linkLabel4_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
        {
            FolderBrowserDialog fo = new FolderBrowserDialog();
            fo.Description = "History folder";
            if (fo.ShowDialog(this) == System.Windows.Forms.DialogResult.OK)
                textBox3.Text = fo.SelectedPath;
        }

        private void linkLabel5_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
        {
            FolderBrowserDialog fo = new FolderBrowserDialog();
            fo.Description = "Downloads folder";
            if (fo.ShowDialog(this) == System.Windows.Forms.DialogResult.OK)
                textBox4_downloadsFolder.Text = fo.SelectedPath;
        }
    }
}
