﻿/*  
     This file is part of Emulators Organizer
    A program that organize emulators and roms.
   
    Copyright (C) 2009 - 2012  Ali Hadid, programmed by Ala Hadid

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.IO;
using System.Windows.Forms;
using AHD.Emulators_Organizer.Base;
using EmulatorsOrganizer.Controls;
using AHD.Utilities;
using System.Diagnostics;

namespace EmulatorsOrganizer.Frms
{
    public partial class Frm_emulatorProperties : Form
    {
        List<string> EmuEXES = new List<string>();
        Emulator _emulator;
        EmuConsole _console;
        public Frm_emulatorProperties(Emulator emulator, EmuConsole console)
        {
            _emulator = emulator;
            _console = console;
            InitializeComponent();
            textBox1_name.Text = emulator.Name;
            textBox1_folder.Text = emulator.Folder;

            RefreshComboBox();
            if (comboBox1.Items.Count > 0)
                comboBox1.SelectedItem = Path.GetFileName(Utilities.GetFullPath(emulator.Path));

            label3.Image = _emulator.Icon;

            //commandlines
            commandlinesEditor1.CommandLinesGroups = _emulator.CommandLinesGroups;

            //config files
            if (emulator.ConfigFiles == null)
                emulator.ConfigFiles = new List<ConfigurationFile> ();
            foreach (ConfigurationFile file in emulator.ConfigFiles)
                listBox1.Items.Add(file);
        }
        void RefreshComboBox()
        {
            comboBox1.Items.Clear();
            EmuEXES.Clear();
            if (Directory.Exists(textBox1_folder.Text))
            {
                string[] dirs = Directory.GetFiles(Utilities.GetFullPath(textBox1_folder.Text), "*", SearchOption.AllDirectories);
                for (int i = 0; i < dirs.Length; i++)
                {
                    if (Path.GetExtension(dirs[i]).ToLower() == ".exe")
                    {
                        comboBox1.Items.Add(Path.GetFileName(dirs[i]));
                        EmuEXES.Add(dirs[i]);
                    }
                }
            }
        }
        private void comboBox1_SelectedIndexChanged(object sender, EventArgs e)
        {
            if (comboBox1.SelectedIndex >= 0)
            {
                textBox1_exe.Text = Utilities.GetDotPath(EmuEXES[comboBox1.SelectedIndex]);
                if (textBox1_name.Text == "")
                    textBox1_name.Text = Path.GetFileNameWithoutExtension(EmuEXES[comboBox1.SelectedIndex]);
                label3.Image = Icon.ExtractAssociatedIcon(EmuEXES[comboBox1.SelectedIndex]).ToBitmap();
            }
            else
            {
                textBox1_exe.Text = "";
                label3.Image = Properties.Resources.cpu;
            }
        }
        private void linkLabel1_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
        {
            FolderBrowserDialog fol = new FolderBrowserDialog();
            fol.Description = "Emulator's folder";
            if (fol.ShowDialog(this) == System.Windows.Forms.DialogResult.OK)
            {
                textBox1_folder.Text = Utilities.GetDotPath(fol.SelectedPath);
                RefreshComboBox();
                if (comboBox1.Items.Count > 0)
                    comboBox1.SelectedIndex = 0;
            }
        }

        private void button2_Click(object sender, EventArgs e)
        {
            DialogResult = System.Windows.Forms.DialogResult.Cancel;
            Close();
        }
        //OK
        private void button1_Click(object sender, EventArgs e)
        {
            //check name
            if (textBox1_name.Text.Length == 0)
            {
                MessageBox.Show("Please enter name !!");
                return;
            }
            foreach (Emulator emu in _console.Emulators)
            {
                if (emu.Name.ToLower() == textBox1_name.Text.ToLower() & emu != _emulator)
                {
                    MessageBox.Show("Name already taken !!");
                    return;
                }
            }
            //folder
            if (!Directory.Exists(textBox1_folder.Text))
            {
                if (MessageBox.Show("It seems that emulator's folder is not exist so this emulator is NOT ACTIVE, are sure you want to continue ?", "", MessageBoxButtons.YesNo, MessageBoxIcon.Hand) == System.Windows.Forms.DialogResult.No)
                {
                    return;
                }
            }
            //exe
            else if (!File.Exists(textBox1_exe.Text))
            {
                if (MessageBox.Show("It seems that emulator's excutible file is not exist so this emulator is NOT ACTIVE, are sure you want to continue ?", "", MessageBoxButtons.YesNo, MessageBoxIcon.Hand) == System.Windows.Forms.DialogResult.No)
                {
                    return;
                }
            }
            _emulator.Icon = label3.Image;
            _emulator.Folder = textBox1_folder.Text;
            _emulator.Name = textBox1_name.Text;
            _emulator.Path = textBox1_exe.Text;
            _emulator.CommandLinesGroups = commandlinesEditor1.CommandLinesGroups;
            //config files
            _emulator.ConfigFiles = new List<ConfigurationFile>();
            foreach (ConfigurationFile file in listBox1.Items)
                _emulator.ConfigFiles.Add(file);
            DialogResult = System.Windows.Forms.DialogResult.OK;
            Close();
        }

        private void label3_MouseClick(object sender, MouseEventArgs e)
        {
            OpenFileDialog Op = new OpenFileDialog();
            Op.Title = "Browse for an icon";
            Op.Filter = "Icon (*.jpg;*.png;*.bmp;*.gif;*.jpeg;*.tiff;*.tga;*.ico;*.exe)|*.jpg;*.png;*.bmp;*.gif;*.jpeg;*.tiff;*.tga;*.ico;*.exe";
            Op.Multiselect = false;
            if (Op.ShowDialog(this) == DialogResult.OK)
            {
                if (Path.GetExtension(Op.FileName).ToLower() == ".exe" | Path.GetExtension(Op.FileName).ToLower() == ".ico")
                { label3.Image = Icon.ExtractAssociatedIcon(Op.FileName).ToBitmap(); }
                else { label3.Image = Image.FromFile(Op.FileName); }
            }
        }

        private void label2_Click(object sender, EventArgs e)
        {
            try
            {
                Process.Start(Utilities.GetFullPath(textBox1_exe.Text));
            }
            catch { }
        }

        private void linkLabel2_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
        {
            OpenFileDialog op = new OpenFileDialog();
            op.Filter = "cofiguration file|*.conf;*.ini|All Files|*.*";
            if (op.ShowDialog(this) == System.Windows.Forms.DialogResult.OK)
            {
                listBox1.Items.Add(new ConfigurationFile(Utilities.GetDotPath(op.FileName)));
            }
        }

        private void linkLabel3_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
        {
            if (listBox1.SelectedIndex >= 0)
                listBox1.Items.RemoveAt(listBox1.SelectedIndex);
        }

        private void listBox1_MouseDoubleClick(object sender, MouseEventArgs e)
        {
            if (listBox1.SelectedIndex < 0)
                return;
            Frm_ConfigFileEditor frm = new Frm_ConfigFileEditor((ConfigurationFile)listBox1.SelectedItem);
            frm.ShowDialog(this);
        }
    }
}
